@@ -1,36 +1,50 @@
 #!/bin/sh
 
-ACLOCAL="aclocal"
+ACLOCAL="aclocal -I ${PWD}/m4"
 AUTOHEADER="autoheader"
-AUTOMAKE="automake -a -c --foreign"
+AUTOMAKE="automake --add-missing --copy --foreign"
 AUTOCONF="autoconf"
-ACINCLUDE_FILES="lyxinclude.m4 libtool.m4 codeset.m4 gettext.m4 glibc21.m4 iconv.m4 isc-posix.m4 lcmessage.m4 progtest.m4 xforms.m4 qt.m4 gtk--.m4 gnome--.m4 gnome.m4 spell.m4 cygwin.m4 pkg.m4"
+ACINCLUDE_FILES="lyxinclude.m4 libtool.m4 xforms.m4 qt.m4 gtk--.m4 gnome--.m4 gnome.m4 spell.m4 pkg.m4"
 
-# Discover what version of autoconf we are using.
-autoversion=`$AUTOCONF --version | head -n 1`
+# Discover what version of automake we are using.
+automake_version=`$AUTOMAKE --version 2>/dev/null | head -n 1`
 
-echo "Using $autoversion"
-case $autoversion in
-    *2.13)
-	cp config/acconfig.h .
-	cp config/configure.in .
-	rm -f configure.ac
-	cp config/relyx_configure.in lib/reLyX/configure.in
-	rm -f lib/reLyX/configure.ac
-	EXTRA_ACINCLUDE_FILES="lyxinclude213.m4"
+test "$automake_version" != "" && {
+    echo "Using $automake_version"
+} || {
+    echo "LyX requires automake >= 1.9"
+    exit 1
+}
+
+case $automake_version in
+    *' '1.9*)
 	;;
-    *2.5[2-9])
-	rm -f acconfig.h
-	rm -f configure.in
-	cp config/configure.ac .
-	rm -f lib/reLyX/configure.in
-	cp config/relyx_configure.ac lib/reLyX/configure.ac
+    *)
+    
+	echo "This automake version is not supported by LyX."
+        echo "LyX only supports automake 1.9."
+        exit 1
+        ;;
+esac
+							
+# Discover what version of autoconf we are using.
+autoversion=`$AUTOCONF --version 2>/dev/null | head -n 1`
+
+test "$autoversion" != "" && {
+    echo "Using $autoversion"
+} || {
+    echo "LyX requires autoconf >= 2.52"
+    exit 1
+}
+	    
+case $autoversion in
+    *' '2.5[2-9])
 	EXTRA_ACINCLUDE_FILES="lyxinclude25x.m4"
 	;;
     *)
 	echo "This autoconf version is not supported by LyX."
-	echo "LyX only supports autoconf 2.13 and 2.5[2-9]."
-	exit
+	echo "LyX only supports autoconf 2.5[2-9]."
+	exit 1
 	;;
 esac
 
@@ -49,11 +63,15 @@ for prog in $M4 gm4 gnum4 m4; do
 done
 if test x$GNUM4 = x ; then
 	echo "not found."
-	exit
+	exit 1
 else
 	echo `which $GNUM4`
 fi
 
+# Delete old cache directories.
+# automake will stop if their contents was created by an earlier version.
+rm -rf autom4te.cache
+
 # Generate acinclude.m4
 echo -n "Generate acinclude.m4... "
 rm -f acinclude.m4
@@ -63,14 +81,14 @@ echo "done."
 # Generate the Makefiles and configure files
 if ( $ACLOCAL --version ) < /dev/null > /dev/null 2>&1; then
 	echo "Building macros..."
-	for dir in . lib/reLyX ; do
+	for dir in . ; do
 	    echo "        $dir"
 	    ( cd $dir ; $ACLOCAL )
 	done
 	echo "done."
 else
 	echo "aclocal not found -- aborting"
-	exit
+	exit 1
 fi
 
 if ( $AUTOHEADER --version ) < /dev/null > /dev/null 2>&1; then
@@ -82,40 +100,33 @@ if ( $AUTOHEADER --version ) < /dev/null > /dev/null 2>&1; then
 	echo "done."
 else
 	echo "autoheader not found -- aborting"
-	exit
+	exit 1
 fi
 
 if ( $AUTOMAKE --version ) < /dev/null > /dev/null 2>&1; then
 	echo "Building Makefile templates..."
-	for dir in . lib/reLyX ; do
+	for dir in . ; do
 	    echo "        $dir"
 	    ( cd $dir ; $AUTOMAKE )
 	done
 	echo "done."
 else
 	echo "automake not found -- aborting"
-	exit
+	exit 1
 fi
 
 if ( $AUTOCONF --version ) < /dev/null > /dev/null 2>&1; then
 	echo "Building configure..."
-	for dir in . lib/reLyX ; do
+	for dir in . ; do
 	    echo "       $dir"
 	    ( cd $dir ; $AUTOCONF )
 	done
 	echo "done."
 else
 	echo "autoconf not found -- aborting"
-	exit
+	exit 1
 fi
 
-# Autogenerate lib/configure.m4.
-echo -n "Building lib/configure ... "
-rm -f lib/configure
-$GNUM4 lib/configure.m4 > lib/configure
-chmod a+x lib/configure
-echo "done."
-
 echo
 echo 'run "./configure ; make"'
 echo
