@@ -25,7 +25,7 @@ import re
 import string
 import time
 
-version_lyx2lyx = "1.3.6"
+version_lyx2lyx = "1.4.1"
 default_debug_level = 2
 
 # Regular expressions used
@@ -111,6 +111,10 @@ class LyX_Base:
 
         self.backend = "latex"
         self.textclass = "article"
+        # This is a hack: We use '' since we don't know the default
+        # layout of the text class. LyX will parse it as default layout.
+        # FIXME: Read the layout file and use the real default layout
+        self.default_layout = ''
         self.header = []
         self.preamble = []
         self.body = []
@@ -291,6 +295,14 @@ class LyX_Base:
         self.header[i] = '\\%s %s' % (param, str(value))
 
 
+    def is_default_layout(self, layout):
+        " Check whether a layout is the default layout of this class."
+        # FIXME: Check against the real text class default layout
+        if layout == 'Standard' or layout == self.default_layout:
+            return 1
+        return 0
+
+
     def convert(self):
         "Convert from current (self.format) to self.end_format."
         mode, convertion_chain = self.chain()
