@@ -1,21 +1,19 @@
 // -*- C++ -*-
-/* This is the bullet class definition file.
- * This file is part of
- * ======================================================
+/**
+ * \file Bullet.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Lars Gullik Bjnnes
+ * \author Allan Rae
  *
- *           Copyright 1995 Matthias Ettrich
- *           Copyright 1995-2001 The LyX Team.
- *
- *           This file Copyright 1997-1999
- *           Allan Rae
- * ====================================================== */
+ * Full author contact details are available in file CREDITS.
+ */
 
 #ifndef BULLET_H
 #define BULLET_H
 
-#include "LString.h"
+#include <string>
 
 ///
 class Bullet {
@@ -24,7 +22,7 @@ public:
 	Bullet(int f = -1, int c = -1, int s = -1);
 
 	///
-	explicit Bullet(string const &);
+	explicit Bullet(std::string const &);
 
 	///
 	void setCharacter(int);
@@ -33,7 +31,7 @@ public:
 	///
 	void setSize(int);
 	///
-	void setText(string const &);
+	void setText(std::string const &);
 	///
 	int getCharacter() const;
 	///
@@ -41,16 +39,14 @@ public:
 	///
 	int getSize() const;
 	///
-	string const & getText() const;
+	std::string const & getText() const;
 	///
 	Bullet & operator=(Bullet const &);
 	///
 	friend bool operator==(Bullet const &, Bullet const &);
 protected:
-#ifdef ENABLE_ASSERTIONS
 	///
 	void testInvariant() const;
-#endif
 private:
 	/**
 	   This enum makes adding additional panels or changing panel sizes
@@ -74,9 +70,9 @@ private:
 	///
 	void generateText() const;
 	///
-	static string const bulletSize(int);
+	static std::string const bulletSize(int);
 	///
-	static string const bulletEntry(int, int);
+	static std::string const bulletEntry(int, int);
 
 	///
 	int font;
@@ -101,7 +97,7 @@ private:
 	    or one generated internally from the font, character
 	    and size settings.
 	*/
-	mutable string text;
+	mutable std::string text;
 };
 
 
