@@ -1,47 +1,48 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file LaTeX.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
- *	     Copyright 1995 Matthias Ettrich
- *           Copyright 1995-2001 The Lyx Team
+ * \author Lars Gullik Bjnnes
+ * \author Angus Leeming
+ * \author Dekel Tsur
  *
- *           This file is Copyright 1996-2001
- *           Lars Gullik Bjnnes
- *
- * ======================================================
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef LATEX_H
 #define LATEX_H
 
-#include "LString.h"
-#include "DepTable.h"
+#include "outputparams.h"
+
+#include <boost/utility.hpp>
+#include <boost/signal.hpp>
+
 #include <vector>
 #include <set>
 
-#include <boost/utility.hpp>
-
-class LyXFunc;
+class DepTable;
 
 ///
 class TeXErrors {
 private:
 	///
-	struct Error {
+	class Error {
+	public:
 		///
 		Error () : error_in_line(0) {}
 		///
-		Error(int line, string const & desc, string const & text)
+		Error(int line, std::string const & desc, std::string const & text)
 			: error_in_line(line),
 			  error_desc(desc),
 			  error_text(text) {}
 		/// what line in the TeX file the error occured in
 		int error_in_line;
 		/// The kind of error
-		string error_desc;
+		std::string error_desc;
 		/// The line/cmd that caused the error.
-		string error_text;
+		std::string error_text;
 	};
 public:
 	///
@@ -51,45 +52,32 @@ public:
 	///
 	Errors::const_iterator end() const { return errors.end(); }
 	///
-	void insertError(int line, string const & error_desc,
-			 string const & error_text);
+	void insertError(int line, std::string const & error_desc,
+			 std::string const & error_text);
 private:
 	///
 	Errors errors;
 };
 
+
 class Aux_Info {
 public:
 	///
 	Aux_Info() {}
 	///
-	string aux_file;
+	std::string aux_file;
 	///
-	std::set<string> citations;
+	std::set<std::string> citations;
 	///
-	std::set<string> databases;
+	std::set<std::string> databases;
 	///
-	std::set<string> styles;
+	std::set<std::string> styles;
 };
 
 
 ///
-inline
-bool operator==(Aux_Info const & a, Aux_Info const & o)
-{
-	return a.aux_file == o.aux_file &&
-		a.citations == o.citations &&
-		a.databases == o.databases &&
-		a.styles == o.styles;
-}
-
-
-///
-inline
-bool operator!=(Aux_Info const & a, Aux_Info const & o)
-{
-	return !(a == o);
-}
+bool operator==(Aux_Info const &, Aux_Info const &);
+bool operator!=(Aux_Info const &, Aux_Info const &);
 
 
 ///
@@ -137,46 +125,47 @@ public:
 		WARNINGS = TEX_WARNING + LATEX_WARNING + PACKAGE_WARNING
 	};
 
+	/// This signal emits an informative message
+	boost::signal<void(std::string)> message;
+
 
 	/**
 	   cmd = the latex command, file = name of the (temporary) latex file,
 	   path = name of the files original path.
 	*/
-	LaTeX(string const & cmd, string const & file, string const & path);
-
-	///
-	virtual ~LaTeX() {}
+	LaTeX(std::string const & cmd, OutputParams const &,
+	      std::string const & file, std::string const & path);
 
 	/// runs LaTeX several times
-	int run(TeXErrors &, LyXFunc *);
+	int run(TeXErrors &);
 
 	///
 	int getNumErrors() { return num_errors;}
 
-	/// use this for running LaTeX once
-	int operator() ();
-
 	///
 	int scanLogFile(TeXErrors &);
 
-protected:
+private:
+	/// use this for running LaTeX once
+	int startscript();
+
 	/// The dependency file.
-	string depfile;
+	std::string depfile;
 
 	///
 	void deplog(DepTable & head);
 
 	///
-	bool runMakeIndex(string const &);
+	bool runMakeIndex(std::string const &, OutputParams const &);
 
 	///
-	std::vector<Aux_Info> const scanAuxFiles(string const &);
+	std::vector<Aux_Info> const scanAuxFiles(std::string const &);
 
 	///
-	Aux_Info const scanAuxFile(string const &);
+	Aux_Info const scanAuxFile(std::string const &);
 
 	///
-	void scanAuxFile(string const &, Aux_Info &);
+	void scanAuxFile(std::string const &, Aux_Info &);
 
 	///
 	void updateBibtexDependencies(DepTable &,
@@ -189,19 +178,22 @@ protected:
 	void deleteFilesOnError() const;
 
 	///
-	string cmd;
+	std::string cmd;
 
 	///
-	string file;
+	std::string file;
 
 	///
-	string path;
+	std::string path;
 
 	/// used by scanLogFile
 	int num_errors;
 
 	/// The name of the final output file.
-	string output_file;
+	std::string output_file;
+
+	///
+	OutputParams runparams;
 };
 
 #endif
