@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file Thesaurus.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef THESAURUS_H
@@ -12,8 +14,8 @@
 
 #include <vector>
 #include <map>
+#include <string>
 
-#include "LString.h"
 #ifdef HAVE_LIBAIKSAURUS
 #include AIKSAURUS_H_LOCATION
 #endif
@@ -29,12 +31,12 @@ public:
 	///
 	~Thesaurus();
 
-	typedef std::map<string, std::vector<string> > Meanings;
+	typedef std::map<std::string, std::vector<std::string> > Meanings;
 
 	/**
 	 * look up some text in the thesaurus
 	 */
-	Meanings lookup(string const & text);
+	Meanings lookup(std::string const & text);
 
 private:
 #ifdef HAVE_LIBAIKSAURUS
