@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file box.h
- * Copyright 2001 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef BOX_H
@@ -20,12 +22,15 @@
  *
  * Negative values are allowed.
  */
-struct Box {
+class Box {
+public:
 	int x1;
 	int x2;
 	int y1;
 	int y2;
 
+	/// Zero-initialise the member variables.
+	Box();
 	/// Initialise the member variables.
 	Box(int x1_, int x2_, int y1_, int y2_);
 
@@ -34,7 +39,7 @@ struct Box {
 	 * the box. Check is exclusive (point on a border
 	 * returns false).
 	 */
-	bool contained(int x, int y);
+	bool contains(int x, int y);
 };
 
 
