@@ -1,26 +1,26 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file debug.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Lars Gullik Bjnnes
+ * \author Jean-Marc Lasgouttes
  *
- *           Copyright 1995 Matthias Ettrich
- *           Copyright 1995-2001 The LyX Team.
- *
- * ====================================================== */
+ * Full author contact details are available in file CREDITS.
+ */
 
 #ifndef LYXDEBUG_H
 #define LYXDEBUG_H
 
-#include <iosfwd>
-
-#include "LString.h"
+#include "support/debugstream.h"
 
 /** Ideally this should have been a namespace, but since we try to be
-    compilable on older C++ compilators too, we use a struct instead.
-    This is all the different debug levels that we have.
-*/
-struct Debug {
+ *  compilable on older C++ compilators too, we use a struct instead.
+ *  This is all the different debug levels that we have.
+ */
+class lyx_debug_trait {
+public:
 	///
 	enum type {
 		///
@@ -68,15 +68,27 @@ struct Debug {
 		///
 		INSETTEXT  = (1 << 20),
 		///
-		GRAPHICS   = (1 << 21)
+		GRAPHICS   = (1 << 21),
+		/// change tracking
+		CHANGES    = (1 << 22),
+		///
+		EXTERNAL   = (1 << 23),
+		///
+		PAINTING   = (1 << 24),
+		///
+		DEBUG      = (1 << 31),
+		///
+		ANY = 0xffffffff
 	};
-	///
-	static type const ANY;
+
+	static bool match(type a, type b) {
+		return (a & b);
+	}
 
 	/** A function to convert symbolic string names on debug levels
 	    to their numerical value.
 	*/
-	static Debug::type value(string const & val);
+	static type value(std::string const & val);
 
 	/** Display the tags and descriptions of the current debug level
 	    of ds
@@ -91,18 +103,17 @@ struct Debug {
 
 
 inline
-void operator|=(Debug::type & d1, Debug::type d2)
+void operator|=(lyx_debug_trait::type & d1, lyx_debug_trait::type d2)
 {
-	d1 = static_cast<Debug::type>(d1 | d2);
+	d1 = static_cast<lyx_debug_trait::type>(d1 | d2);
 }
 
 
-#include "support/DebugStream.h"
+// std::ostream & operator<<(std::ostream & o, Debug::type t);
 
+typedef basic_debugstream<lyx_debug_trait> LyXErr;
+typedef LyXErr::debug Debug;
 
-
-std::ostream & operator<<(std::ostream & o, Debug::type t);
-
-extern DebugStream lyxerr;
+extern LyXErr lyxerr;
 
 #endif
