@@ -7,27 +7,23 @@
  * \author Lars Gullik Bjnnes
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef LYXVIEW_H
 #define LYXVIEW_H
 
-#include "LString.h"
-
-#include "support/types.h"
-
-#include <boost/utility.hpp>
 #include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
+#include <boost/signal.hpp>
 #include <boost/signals/trackable.hpp>
-#include <boost/signals/signal0.hpp>
+#include <boost/utility.hpp>
 
 class Buffer;
-class Toolbar;
+class Toolbars;
+class InsetBase;
 class Intl;
 class Menubar;
-class ControlCommandBuffer;
 
 class BufferView;
 class Dialogs;
@@ -36,6 +32,12 @@ class LyXFont;
 class Timeout;
 class FuncRequest;
 
+namespace lyx {
+namespace frontend {
+class ControlCommandBuffer;
+} // namespace frontend
+} // namespace lyx
+
 /**
  * LyXView - main LyX window
  *
@@ -63,10 +65,8 @@ public:
 	 */
 	void init();
 
-	/// start modal operation
-	virtual void prohibitInput() const = 0;
-	/// end modal operation
-	virtual void allowInput() const = 0;
+	/// show busy cursor
+	virtual void busy(bool) const = 0;
 
 	//@{ generic accessor functions
 
@@ -85,9 +85,9 @@ public:
 	LyXFunc const & getLyXFunc() const { return *lyxfunc_.get(); }
 
 	/// return the toolbar for this view
-	Toolbar & getToolbar() { return *toolbar_.get(); }
+	Toolbars & getToolbars() { return *toolbars_.get(); }
 	///
-	Toolbar const & getToolbar() const { return *toolbar_.get(); }
+	Toolbars const & getToolbars() const { return *toolbars_.get(); }
 
 	/// return the menubar for this view
 	Menubar & getMenubar() { return *menubar_.get(); }
@@ -107,23 +107,26 @@ public:
 	//@}
 
 	/// sets the layout in the toolbar layout selection
-	void setLayout(string const & layout);
+	void setLayout(std::string const & layout);
 	/// updates the possible layouts selectable
 	void updateLayoutChoice();
 
 	/// update the toolbar
-	void updateToolbar();
+	void updateToolbars();
 	/// update the menubar
 	void updateMenubar();
 
 	/// focus the command buffer (minibuffer)
-	boost::signal0<void> focus_command_buffer;
+	boost::signal<void()> focus_command_buffer;
 
 	/// view state string changed
-	boost::signal0<void> view_state_changed;
+	boost::signal<void()> view_state_changed;
 
 	/// display a message in the view
-	virtual void message(string const &) = 0;
+	virtual void message(std::string const &) = 0;
+
+	/// clear any temporary message and replace with current status
+	virtual void clearMessage() = 0;
 
 	/// updates the title of the window
 	void updateWindowTitle();
@@ -132,7 +135,15 @@ public:
 	void resetAutosaveTimer();
 
 	/// dispatch to current BufferView
-	void dispatch(FuncRequest const & req);
+	void dispatch(FuncRequest const & cmd);
+
+	/** redraw \c inset in all the BufferViews in which it is currently
+	 *  visible. If successful return a pointer to the owning Buffer.
+	 */
+	Buffer const * const updateInset(InsetBase const *) const;
+
+	// returns true if this view has the focus.
+	virtual bool hasFocus() const = 0;
 
 protected:
 	/// view of a buffer. Eventually there will be several.
@@ -140,8 +151,6 @@ protected:
 
 	/// view's menubar
 	boost::scoped_ptr<Menubar> menubar_;
-	/// view's toolbar
-	boost::scoped_ptr<Toolbar> toolbar_;
 
 private:
 	/**
@@ -149,11 +158,13 @@ private:
 	 * @param t main window title
 	 * @param it iconified (short) title
 	 */
-	virtual void setWindowTitle(string const & t, string const & it) = 0;
+	virtual void setWindowTitle(std::string const & t, std::string const & it) = 0;
 
 	/// called on timeout
 	void autoSave();
 
+	/// view's toolbar
+	boost::scoped_ptr<Toolbars> toolbars_;
 	/// keyboard mapping object
 	boost::scoped_ptr<Intl> const intl_;
 	/// auto-saving of buffers
@@ -167,7 +178,10 @@ protected:
 	/// view's command buffer controller
 	// this has to be declared _after_ lyxfunc_ as its initialization depends
 	// on it!
-	boost::scoped_ptr<ControlCommandBuffer> const controlcommand_;
+	typedef boost::scoped_ptr<lyx::frontend::ControlCommandBuffer>
+	CommandBufferPtr;
+
+	CommandBufferPtr const controlcommand_;
 };
 
 #endif // LYXVIEW_H
