@@ -1,3 +1,4 @@
+// -*- C++ -*-
 /**
  * \file WorkAreaFactory.h
  * This file is part of LyX, the document processor.
@@ -5,20 +6,21 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef WORKAREAFACTORY_H
 #define WORKAREAFACTORY_H
 
 class WorkArea;
+class LyXView;
 
 namespace WorkAreaFactory {
 	/**
 	 * Make a work area. Used because we want to generate
 	 * a toolkit-specific instance.
 	 */
-	WorkArea * create(int x, int y, int w, int h);
+	WorkArea * create(LyXView & owner, int w, int h);
 }
 
 #endif // WORKAREA_FACTORY_H
