@@ -6,23 +6,36 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLCHARACTER_H
 #define CONTROLCHARACTER_H
 
-#include "ControlDialog_impl.h"
+
+#include "Dialog.h"
 #include "character.h"
 
-#include <boost/scoped_ptr.hpp>
 
-/** A controller for Character dialogs.
- */
-class ControlCharacter : public ControlDialogBD {
+class LColor_color;
+
+namespace lyx {
+namespace frontend {
+
+class ControlCharacter : public Dialog::Controller {
 public:
 	///
-	ControlCharacter(LyXView &, Dialogs &);
+	ControlCharacter(Dialog &);
+	///
+	virtual bool initialiseParams(std::string const & data);
+	///
+	virtual void clearParams();
+	///
+	virtual void dispatchParams();
+	///
+	virtual bool isBufferDependent() const { return true; }
+	///
+	virtual kb_action getLfun() const { return LFUN_FREEFONT_UPDATE; }
 
 	///
 	void setFamily(LyXFont::FONT_FAMILY);
@@ -33,11 +46,11 @@ public:
 	///
 	void setSize(LyXFont::FONT_SIZE);
 	///
-	void setBar(frnt::FONT_STATE);
+	void setBar(FONT_STATE);
 	///
-	void setColor(LColor::color);
+	void setColor(LColor_color);
 	///
-	void setLanguage(string const &);
+	void setLanguage(std::string const &);
 	///
 	void setToggleAll(bool);
 
@@ -50,24 +63,21 @@ public:
 	///
 	LyXFont::FONT_SIZE getSize() const;
 	///
-	frnt::FONT_STATE getBar() const;
+	FONT_STATE getBar() const;
 	///
-	LColor::color getColor() const;
+	LColor_color getColor() const;
 	///
-	string getLanguage() const;
+	std::string getLanguage() const;
 	///
 	bool getToggleAll() const;
-
-	/// Get changed parameters and Dispatch them to the kernel.
-	virtual void apply();
 private:
-	/// set the params before show or update.
-	virtual void setParams();
-
 	///
 	boost::scoped_ptr<LyXFont> font_;
 	///
 	bool toggleall_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLCHARACTER_H
