@@ -6,44 +6,50 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLCITATION_H
 #define CONTROLCITATION_H
 
+
 #include "ControlCommand.h"
-#include "biblio.h" // biblio::InfoMap
+#include "biblio.h"
+
+namespace lyx {
+namespace frontend {
 
 /** A controller for Citation dialogs.
  */
 class ControlCitation : public ControlCommand {
 public:
 	///
-	ControlCitation(LyXView &, Dialogs &);
+	ControlCitation(Dialog &);
+
+	///
+	virtual bool initialiseParams(std::string const & data);
+	/// clean-up on hide.
+	virtual void clearParams();
+
+	/** Disconnect from the inset when the Apply button is pressed.
+	 *  Allows easy insertion of multiple citations.
+	 */
+	virtual bool disconnectOnApply() const { return true; }
 
 	/// Returns a reference to the map of stored keys
 	biblio::InfoMap const & bibkeysInfo() const;
 
 	///
-	bool usingNatbib() const;
-	/// Possible citations based on this key
-	std::vector<string> const getCiteStrings(string const & key) const;
+	biblio::CiteEngine_enum getEngine() const;
 
-	/// available CiteStyle-s (depends on availability of Natbib
+	/// Possible citations based on this key
+	std::vector<std::string> const getCiteStrings(std::string const & key) const;
+
+	/// available CiteStyle-s (depends on availability of Natbib/Jurabib)
 	static std::vector<biblio::CiteStyle> const & getCiteStyles() {
 		return citeStyles_;
 	}
 private:
-	/// create the InfoMap of keys and data
-	virtual void setDaughterParams();
-	///
-	virtual void clearDaughterParams();
-
-	/** disconnect from the inset when the Apply button is pressed.
-	 Allows easy insertion of multiple citations. */
-	virtual bool disconnectOnApply() { return true; }
-
 	/// The info associated with each key
 	biblio::InfoMap bibkeysInfo_;
 
@@ -51,5 +57,7 @@ private:
 	static std::vector<biblio::CiteStyle> citeStyles_;
 };
 
+} // namespace frontend
+} // namespace lyx
 
 #endif // CONTROLCITATION_H
