@@ -5,20 +5,23 @@
  * Licence details can be found in the file COPYING.
  *
  * \author Lars
- * \author Asger and Juergen
+ * \author Asger and Jrgen
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLCOMMANDBUFFER_H
 #define CONTROLCOMMANDBUFFER_H
 
-#include "LString.h"
-
+#include <string>
 #include <vector>
 
-class LyXFunc;
+
+class LyXView;
+
+namespace lyx {
+namespace frontend {
 
 /**
  * ControlCommandBuffer
@@ -28,32 +31,38 @@ class LyXFunc;
  */
 class ControlCommandBuffer {
 public:
-	ControlCommandBuffer(LyXFunc & lf);
+	ControlCommandBuffer(LyXView & lv);
 
 	/// return the previous history entry if any
-	string const historyUp();
+	std::string const historyUp();
 
 	/// return the next history entry if any
-	string const historyDown();
+	std::string const historyDown();
+
+	/// return the font and depth in the active BufferView as a message.
+	std::string const getCurrentState() const;
 
 	/// return the possible completions
-	std::vector<string> const completions(string const & prefix,
-					      string & new_prefix);
+	std::vector<std::string> const completions(std::string const & prefix,
+					      std::string & new_prefix);
 
 	/// dispatch a command
-	void dispatch(string const & str);
+	void dispatch(std::string const & str);
 private:
-	/// controlling lyxfunc
-	LyXFunc & lyxfunc_;
+	/// controlling LyXView
+	LyXView & lv_;
 
 	/// available command names
-	std::vector<string> commands_;
+	std::vector<std::string> commands_;
 
 	/// command history
-	std::vector<string> history_;
+	std::vector<std::string> history_;
 
 	/// current position in command history
-	std::vector<string>::const_iterator history_pos_;
+	std::vector<std::string>::const_iterator history_pos_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLCOMMANDBUFFER_H
