@@ -6,47 +6,46 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLPARAGRAPH_H
 #define CONTROLPARAGRAPH_H
 
-#include <boost/scoped_ptr.hpp>
-
-#include "ControlDialog_impl.h"
+#include "Dialog.h"
 #include "layout.h" // for LyXAlignment
 
 class ParagraphParameters;
 
-/** A controller for Paragraph dialogs.
- */
-class ControlParagraph : public ControlDialogBD {
+namespace lyx {
+namespace frontend {
+
+class ControlParagraph : public Dialog::Controller {
 public:
 	///
-	ControlParagraph(LyXView &, Dialogs &);
-	/** Declaring this out of line allows us to forward declare
-	    ParagraphParameters without upsetting boost::scoped_ptr. */
-	~ControlParagraph();
-
+	ControlParagraph(Dialog &);
+	///
+	virtual bool initialiseParams(std::string const & data);
+	/// clean-up on hide.
+	virtual void clearParams();
+	///
+	virtual void dispatchParams();
+	///
+	virtual bool isBufferDependent() const { return true; }
 	///
 	ParagraphParameters & params();
 	///
+	ParagraphParameters const & params() const;
+	///
 	bool inInset() const;
 	///
 	LyXAlignment alignPossible() const;
 	///
 	LyXAlignment alignDefault() const;
-	///
-	void changedParagraph();
-private:
-	/// Get changed parameters and Dispatch them to the kernel.
-	virtual void apply();
-	/// set the params before show or update.
-	virtual void setParams();
 
+private:
 	///
-	boost::scoped_ptr<ParagraphParameters> pp_;
+	boost::scoped_ptr<ParagraphParameters> params_;
 	///
 	bool ininset_;
 	///
@@ -55,4 +54,7 @@ private:
 	LyXAlignment aligndefault_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLPARAGRAPH_H
