@@ -6,36 +6,44 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLREF_H
 #define CONTROLREF_H
 
+
 #include "ControlCommand.h"
+#include <vector>
+
+namespace lyx {
+namespace frontend {
 
 /** A controller for the Ref Dialog.
  */
 class ControlRef : public ControlCommand {
 public:
 	///
-	ControlRef(LyXView &, Dialogs &);
+	ControlRef(Dialog &);
 	///
-	std::vector<string> const getLabelList(string const &) const;
+	std::vector<std::string> const getLabelList(std::string const &) const;
 	///
-	void gotoRef(string const &);
+	void gotoRef(std::string const &);
 	///
 	void gotoBookmark();
 	///
-	std::vector<string> const getBufferList() const;
+	std::vector<std::string> const getBufferList() const;
 	///
 	int getBufferNum() const;
 	///
-	string const getBufferName(int num) const;
+	std::string const getBufferName(int num) const;
 private:
 	/** disconnect from the inset when the Apply button is pressed.
 	 Allows easy insertion of multiple references. */
-	virtual bool disconnectOnApply() { return true; }
+	virtual bool disconnectOnApply() const { return true; }
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLREF_H
