@@ -6,52 +6,58 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 
 #ifndef CONTROLTHESAURUS_H
 #define CONTROLTHESAURUS_H
 
-#include <vector>
-
-#include "LString.h"
+#include "Dialog.h"
 #include "Thesaurus.h"
-#include "ControlDialog_impl.h"
+
+namespace lyx {
+namespace frontend {
 
 /** A controller for Thesaurus dialogs.
  */
-class ControlThesaurus : public ControlDialogBD {
+class ControlThesaurus : public Dialog::Controller {
 public:
 	///
-	ControlThesaurus(LyXView &, Dialogs &);
+	ControlThesaurus(Dialog &);
+	///
+	virtual bool initialiseParams(std::string const & data);
+	///
+	virtual void clearParams();
+	///
+	virtual void dispatchParams() {}
+	///
+	virtual bool isBufferDependent() const { return true; }
 
 	/// replace the particular string
-	void replace(string const & newstr);
-
-	/// show dialog
-	virtual void showEntry(string const & str);
+	void replace(std::string const & newstr);
 
 	/// get meanings
-	Thesaurus::Meanings const & getMeanings(string const & str);
+	Thesaurus::Meanings const & getMeanings(std::string const & str);
 
 	/// the text
-	string const & text() {
-		return oldstr_;
-	}
+	std::string const & text() const { return oldstr_; }
 
 private:
 	/// last string looked up
-	string laststr_;
+	std::string laststr_;
 
 	/// entries for last string
 	Thesaurus::Meanings meanings_;
 
 	/// original string
-	string oldstr_;
+	std::string oldstr_;
 
 	/// not needed.
 	virtual void apply() {}
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLTHESAURUS_H
