@@ -6,34 +6,41 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CONTROLTOC_H
 #define CONTROLTOC_H
 
-#include <vector>
+
 #include "ControlCommand.h"
 #include "toc.h"
+#include <vector>
+
+namespace lyx {
+namespace frontend {
 
 /** A controller for TOC dialogs.
  */
 class ControlToc : public ControlCommand {
 public:
 	///
-	ControlToc(LyXView &, Dialogs &);
+	ControlToc(Dialog &);
 
 	/// Goto this paragraph id
-	void goTo(toc::TocItem const &) const;
+	void goTo(toc::TocItem const &);
 
 	/// Return the list of types available
-	std::vector<string> const getTypes() const;
+	std::vector<std::string> const getTypes() const;
 
 	/// Return the guiname from a given cmdName of the TOC param
-	std::string const getGuiName() const;
+	std::string const getGuiName(std::string const & type) const;
 
 	/// Given a type, returns the contents
-	toc::Toc const getContents(string const & type) const;
+	toc::Toc const getContents(std::string const & type) const;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // CONTROLTOC_H
