@@ -6,20 +6,25 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef CHARACTERHELPERS_H
 #define CHARACTERHELPERS_H
 
+
 #include "lyxfont.h"
-#include "LColor.h"
 
 #include <utility>
 #include <vector>
 
+
+class LColor_color;
+
+
 /** Functions of use to the character GUI controller and view */
-namespace frnt {
+namespace lyx {
+namespace frontend {
 
 ///
 enum FONT_STATE {
@@ -36,17 +41,17 @@ enum FONT_STATE {
 };
 
 ///
-typedef std::pair<string, LyXFont::FONT_FAMILY> FamilyPair;
+typedef std::pair<std::string, LyXFont::FONT_FAMILY> FamilyPair;
 ///
-typedef std::pair<string, LyXFont::FONT_SERIES> SeriesPair;
+typedef std::pair<std::string, LyXFont::FONT_SERIES> SeriesPair;
 ///
-typedef std::pair<string, LyXFont::FONT_SHAPE>  ShapePair;
+typedef std::pair<std::string, LyXFont::FONT_SHAPE>  ShapePair;
 ///
-typedef std::pair<string, LyXFont::FONT_SIZE>   SizePair;
+typedef std::pair<std::string, LyXFont::FONT_SIZE>   SizePair;
 ///
-typedef std::pair<string, FONT_STATE> BarPair;
+typedef std::pair<std::string, FONT_STATE> BarPair;
 ///
-typedef std::pair<string, LColor::color> ColorPair;
+typedef std::pair<std::string, LColor_color> ColorPair;
 
 ///
 std::vector<FamilyPair>   const getFamilyData();
@@ -61,6 +66,7 @@ std::vector<BarPair>      const getBarData();
 ///
 std::vector<ColorPair>    const getColorData();
 
-} // namespace frnt
+} // namespace frontend
+} // namespace lyx
 
 #endif // CHARACTERHELPERS
