@@ -6,28 +6,30 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
+ *
+ * Ease the use of internationalised language strings in the dialogs.
  */
 
 #ifndef FRNT_LANG_H
 #define FRNT_LANG_H
 
-#include "LString.h"
+#include <string>
 #include <utility>
 #include <vector>
 
-/** Ease the use of internationalised language strings in the dialogs.
- */
-namespace frnt {
+namespace lyx {
+namespace frontend {
 
 ///
-typedef std::pair<string, string> LanguagePair;
+typedef std::pair<std::string, std::string> LanguagePair;
 
 /** If the caller is the character dialog, add "No change" and "Reset"
  *  to the vector.
  */
 std::vector<LanguagePair> const getLanguageData(bool character_dlg);
 
-} // namespace frnt
+} // namespace frontend
+} // namespace lyx
 
 #endif // FRNT_LANG_H
