@@ -6,15 +6,24 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FILEDIALOG_PRIVATE_H
 #define FILEDIALOG_PRIVATE_H
 
+
 #include "frontends/FileDialog.h"
 #include <qfiledialog.h>
-#include "LString.h"
+
+namespace lyx {
+namespace support {
+
+class FileFilterList;
+
+} // namespace support
+} // namespace lyx
+
 
 class QToolButton;
 
@@ -22,17 +31,19 @@ class LyXFileDialog : public QFileDialog
 {
 	Q_OBJECT
 public:
-	LyXFileDialog(string const & p, string const & m, string const & t,
+	LyXFileDialog(std::string const & path,
+		      lyx::support::FileFilterList const & filters,
+		      std::string const & title,
 		      FileDialog::Button const & b1,
 		      FileDialog::Button const & b2);
 public slots:
 	void buttonClicked();
 private:
 	QToolButton * b1_;
-	string b1_dir_;
+	std::string b1_dir_;
 
 	QToolButton * b2_;
-	string b2_dir_;
+	std::string b2_dir_;
 };
 
 #endif // FILEDIALOG_PRIVATE_H
