@@ -6,24 +6,27 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QBIBTEX_H
 #define QBIBTEX_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlBibtex;
 class QBibtexDialog;
 
 class QBibtex
-	: public Qt2CB<ControlBibtex, Qt2DB<QBibtexDialog> >
+	: public QController<ControlBibtex, QView<QBibtexDialog> >
 {
 public:
 	friend class QBibtexDialog;
 
-	QBibtex();
+	QBibtex(Dialog &);
 protected:
 	virtual bool isValid();
 private:
@@ -35,4 +38,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QBIBTEX_H
