@@ -7,32 +7,32 @@
  * \author Edwin Leuven
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QCHARACTER_H
 #define QCHARACTER_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
 #include "controllers/character.h"
 #include "controllers/frnt_lang.h"
 
-#include "LString.h"
-
 #include <vector>
 
+namespace lyx {
+namespace frontend {
 
 class ControlCharacter;
 class QCharacterDialog;
 
 
 class QCharacter
-	: public Qt2CB<ControlCharacter, Qt2DB<QCharacterDialog> >
+	: public QController<ControlCharacter, QView<QCharacterDialog> >
 {
 public:
 	friend class QCharacterDialog;
 
-	QCharacter();
+	QCharacter(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -41,13 +41,16 @@ private:
 	/// build the dialog
 	virtual void build_dialog();
 
-	std::vector<frnt::FamilyPair> family;
-	std::vector<frnt::SeriesPair> series;
-	std::vector<frnt::ShapePair>  shape;
-	std::vector<frnt::SizePair>   size;
-	std::vector<frnt::BarPair>    bar;
-	std::vector<frnt::ColorPair>  color;
-	std::vector<frnt::LanguagePair> language;
+	std::vector<FamilyPair> family;
+	std::vector<SeriesPair> series;
+	std::vector<ShapePair>  shape;
+	std::vector<SizePair>   size;
+	std::vector<BarPair>    bar;
+	std::vector<ColorPair>  color;
+	std::vector<LanguagePair> language;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QCHARACTER_H
