@@ -7,7 +7,7 @@
  * \author Edwin Leuven
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QCHARACTERDIALOG_H
@@ -16,12 +16,11 @@
 #include "QCharacter.h"
 #include "ui/QCharacterDialogBase.h"
 
-#include <qevent.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-
 class LyXFont;
 
+namespace lyx {
+namespace frontend {
+
 class QCharacterDialog : public QCharacterDialogBase {
 	Q_OBJECT
 public:
@@ -34,4 +33,7 @@ protected slots:
 	void change_adaptor();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QCHARACTERDIALOG_H
