@@ -7,38 +7,33 @@
  * \author Angus Leeming
  * \author Kalle Dalheimer
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QCITATION_H
 #define QCITATION_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-#include "Qt2Base.h"
+#include "QDialogView.h"
+#include <vector>
 
 class QListBox;
+
+namespace lyx {
+namespace frontend {
+
 class ControlCitation;
 class QCitationDialog;
 
 
-class QCitation
-	: public Qt2CB<ControlCitation, Qt2DB<QCitationDialog> >
+class QCitation : public QController<ControlCitation, QView<QCitationDialog> >
 {
 public:
 	friend class QCitationDialog;
 	///
-	QCitation();
+	QCitation(Dialog &);
+protected:
+	virtual bool isValid();
 private:
-	///
-	enum State {
-		///
-		ON,
-		///
-		OFF
-	};
 
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -55,16 +50,19 @@ private:
 	/// set the styles combo
 	void updateStyle();
 
-	void updateBrowser(QListBox *, std::vector<string> const &) const;
-	///
-	void setBibButtons(State) const;
-	///
-	void setCiteButtons(State) const;
+	void updateBrowser(QListBox *, std::vector<std::string> const &) const;
+	/// check if apply has been pressed
+	bool open_find_;
 
-	///
-	std::vector<string> citekeys;
-	///
-	std::vector<string> bibkeys;
+	/// selected keys
+	std::vector<std::string> citekeys;
+	/// available bib keys
+	std::vector<std::string> bibkeys;
+	/// selected natbib style
+	int style_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QCITATION_H
