@@ -6,23 +6,27 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QCOMMANDBUFFER_H
 #define QCOMMANDBUFFER_H
 
-#include <qtoolbar.h>
+#include <qwidget.h>
 
-class QtView;
-class QCommandEdit;
 class QListBoxItem;
+
+namespace lyx {
+namespace frontend {
+
+class QCommandEdit;
+class QtView;
 class ControlCommandBuffer;
 
-class QCommandBuffer : public QToolBar {
+class QCommandBuffer : public QWidget {
 	Q_OBJECT
 public:
-	QCommandBuffer(QtView * view, ControlCommandBuffer & control);
+	QCommandBuffer(QtView * view, QWidget * parent, ControlCommandBuffer & control);
 
 	/// focus the edit widget
 	void focus_command();
@@ -50,4 +54,7 @@ private:
 	QCommandEdit * edit_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QCOMMANDBUFFER_H
