@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QCOMMANDEDIT_H
@@ -14,6 +14,9 @@
 
 #include <qlineedit.h>
 
+namespace lyx {
+namespace frontend {
+
 class QCommandEdit : public QLineEdit {
 	Q_OBJECT
 public:
@@ -29,9 +32,15 @@ signals:
 	void downPressed();
 
 	/// complete
-	void rightPressed();
+	void tabPressed();
+
 protected:
+	virtual bool event(QEvent * e);
+
 	virtual void keyPressEvent(QKeyEvent * e);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QCOMMANDEDIT_H
