@@ -6,40 +6,47 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QDELIMITERDIALOG_H
 #define QDELIMITERDIALOG_H
 
 #include "ui/QDelimiterDialogBase.h"
-#include "LString.h"
+#include <string>
 
-class QMath;
 class IconPalette;
 class QLabel;
 
+namespace lyx {
+namespace frontend {
+
+class QMathDelimiter;
+
 class QDelimiterDialog : public QDelimiterDialogBase {
 	Q_OBJECT
 public:
-	QDelimiterDialog(QMath * form);
+	QDelimiterDialog(QMathDelimiter * form);
 public slots:
-	void ldelim_clicked(const string & str);
-	void rdelim_clicked(const string & str);
+	void ldelim_clicked(const std::string & str);
+	void rdelim_clicked(const std::string & str);
 	void insertClicked();
 protected:
 	//needed ? virtual void closeEvent(QCloseEvent * e);
 private:
-	void set_label(QLabel * label, string const & str);
+	void set_label(QLabel * label, const std::string & str);
 
 	/// symbol of left delimiter
-	string left_;
+	std::string left_;
 
 	/// symbol of right delimiter
-	string right_;
+	std::string right_;
 
 	/// owning form
-	QMath * form_;
+	QMathDelimiter * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QDELIMITERDIALOG_H
