@@ -6,31 +6,38 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
-
 #ifndef QDOCUMENT_H
 #define QDOCUMENT_H
 
-#include "Qt2Base.h"
-#include "Qt2BC.h"
-
+#include "QDialogView.h"
+#include "BranchList.h"
 #include <boost/scoped_ptr.hpp>
+#include <string>
+#include <vector>
 
-class ControlDocument;
-class QDocumentDialog;
 class LengthCombo;
 class  QLineEdit;
 
+namespace lyx {
+namespace frontend {
+
+class ControlDocument;
+class QDocumentDialog;
+
 class QDocument
-	: public Qt2CB<ControlDocument, Qt2DB<QDocumentDialog> >
+	: public QController<ControlDocument, QView<QDocumentDialog> >
 {
 public:
 
 	friend class QDocumentDialog;
 
-	QDocument();
+	QDocument(Dialog &);
+
+	void showPreamble();
+
 private:
 	/// Apply changes
 	void apply();
@@ -44,7 +51,12 @@ private:
 	void useClassDefaults();
 
 	/// FIXME
-	std::vector<string> lang_;
+	std::vector<std::string> lang_;
+	/// Contains all legal branches for this doc
+	BranchList branchlist_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QDOCUMENT_H
