@@ -6,24 +6,27 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QERT_H
 #define QERT_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlERT;
 class QERTDialog;
 
-class QERT
-	: public Qt2CB<ControlERT, Qt2DB<QERTDialog> >
+
+class QERT : public QController<ControlERT, QView<QERTDialog> >
 {
 public:
 	friend class QERTDialog;
 
-	QERT();
+	QERT(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -33,4 +36,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QERT_H
