@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QERTDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QERTDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QERT;
 
 class QERTDialog : public QERTDialogBase {
@@ -28,4 +31,7 @@ private:
 	QERT * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QERTDIALOG_H
