@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QEXTERNALDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QExternalDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QExternal;
 
 class QExternalDialog : public QExternalDialogBase {
@@ -23,16 +26,25 @@ public:
 
 	virtual void show();
 protected slots:
+	virtual void bbChanged();
+	virtual void browseClicked();
 	virtual void change_adaptor();
 	virtual void editClicked();
-	virtual void viewClicked();
-	virtual void updateClicked();
-	virtual void browseClicked();
+	virtual void extraChanged(const QString&);
+	virtual void formatChanged(const QString&);
+	virtual void getbbClicked();
+	virtual void sizeChanged();
 	virtual void templateChanged();
+	virtual void widthUnitChanged();
+
 protected:
 	virtual void closeEvent(QCloseEvent * e);
 private:
+	bool activateAspectratio() const;
 	QExternal * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QEXTERNALDIALOG_H
