@@ -6,26 +6,28 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QFLOAT_H
 #define QFLOAT_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
+
 
 class ControlFloat;
 class QFloatDialog;
 
 ///
-class QFloat
-	: public Qt2CB<ControlFloat, Qt2DB<QFloatDialog> >
-{
+class QFloat : public QController<ControlFloat, QView<QFloatDialog> > {
 public:
 	///
 	friend class QFloatDialog;
 	///
-	QFloat();
+	QFloat(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -35,4 +37,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QFLOAT_H
