@@ -6,7 +6,7 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QFLOATDIALOG_H
@@ -14,21 +14,27 @@
 
 #include "ui/QFloatDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QFloat;
 
 class QFloatDialog : public QFloatDialogBase {
 	Q_OBJECT
 public:
 	QFloatDialog(QFloat * form);
+
 protected slots:
 	virtual void change_adaptor();
-	virtual void tbhpClicked();
-	virtual void heredefinitelyClicked();
-	virtual void spanClicked();
+
 protected:
 	virtual void closeEvent(QCloseEvent * e);
+
 private:
 	QFloat * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QFLOATDIALOG_H
