@@ -5,29 +5,32 @@
  * Licence details can be found in the file COPYING.
  *
  * \author John Levon
- * \author Herbert Voss
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QGRAPHICS_H
 #define QGRAPHICS_H
 
-#include "insets/insetgraphics.h"
-#include "Qt2Base.h"
+#include "QDialogView.h"
+#include <vector>
+
+namespace lyx {
+namespace frontend {
 
 class ControlGraphics;
 class QGraphicsDialog;
 
 ///
 class QGraphics
-	: public Qt2CB<ControlGraphics, Qt2DB<QGraphicsDialog> >
+	: public QController<ControlGraphics, QView<QGraphicsDialog> >
 {
 public:
 	///
 	friend class QGraphicsDialog;
 	///
-	QGraphics();
+	QGraphics(Dialog &);
 protected:
 	virtual bool isValid();
 private:
@@ -41,8 +44,11 @@ private:
 	void getBB();
 
 	/// Store the LaTeX names for the rotation origins.
-	std::vector<string> origin_ltx;
+	std::vector<std::string> origin_ltx;
 
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QGRAPHICS_H
