@@ -5,9 +5,9 @@
  * Licence details can be found in the file COPYING.
  *
  * \author John Levon
- * \author Herbert Voss
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QGRAPHICSDIALOG_H
@@ -15,6 +15,9 @@
 
 #include "ui/QGraphicsDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QGraphics;
 
 class QGraphicsDialog : public QGraphicsDialogBase {
@@ -29,10 +32,14 @@ protected slots:
 	virtual void change_WUnit();
 	virtual void browse_clicked();
 	virtual void getBB_clicked();
+	virtual void edit_clicked();
 protected:
 	virtual void closeEvent(QCloseEvent * e);
 private:
 	QGraphics * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QGRAPHICSDIALOG_H
