@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QINCLUDEDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QIncludeDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QInclude;
 
 class QIncludeDialog : public QIncludeDialogBase {
@@ -35,4 +38,7 @@ private:
 	QInclude * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QINCLUDEDIALOG_H
