@@ -7,25 +7,28 @@
  * \author John Levon
  * \author Kalle Dalheimer
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QINDEX_H
 #define QINDEX_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
 
-class ControlIndex;
+namespace lyx {
+namespace frontend {
+
+class ControlCommand;
 class QIndexDialog;
 
 
 class QIndex :
-	public Qt2CB<ControlIndex, Qt2DB<QIndexDialog> >
+	public QController<ControlCommand, QView<QIndexDialog> >
 {
 public:
 	friend class QIndexDialog;
 
-	QIndex();
+	QIndex(Dialog &, std::string const & title, QString const & label);
 protected:
 	virtual bool isValid();
 private:
@@ -35,6 +38,12 @@ private:
 	virtual void update_contents();
 	/// build the dialog
 	virtual void build_dialog();
+
+	///
+	QString const label_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QINDEX_H
