@@ -7,18 +7,17 @@
  * \author John Levon
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QLPRINTDIALOG_H
 #define QLPRINTDIALOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ui/QPrintDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QPrint;
 
 class QLPrintDialog : public QPrintDialogBase {
@@ -36,4 +35,7 @@ private:
 	QPrint * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QLPRINTDIALOG_H
