@@ -6,26 +6,29 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QLOG_H
 #define QLOG_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlLog;
 class QLogDialog;
 
 ///
 class QLog
-	: public Qt2CB<ControlLog, Qt2DB<QLogDialog> >
+	: public QController<ControlLog, QView<QLogDialog> >
 {
 public:
 	///
 	friend class QLogDialog;
 	///
-	QLog();
+	QLog(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply() {}
@@ -35,4 +38,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QLOG_H
