@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QLOGDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QLogDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QLog;
 
 class QLogDialog : public QLogDialogBase {
@@ -28,4 +31,7 @@ private:
 	QLog * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QLOGDIALOG_H
