@@ -4,16 +4,15 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Asger and Juergen
+ * \author Asger and Jrgen
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QLYXKEYSYM_H
 #define QLYXKEYSYM_H
 
-#include "LString.h"
 #include "frontends/LyXKeySym.h"
 
 #include <qstring.h>
@@ -35,7 +34,7 @@ public:
 	void set(QKeyEvent * ev);
 
 	/// set from a LyX symbolic name
-	virtual void init(string const & symbolname);
+	virtual void init(std::string const & symbolname);
 
 	/// Is this a valid key?
 	virtual bool isOK() const;
@@ -44,17 +43,24 @@ public:
 	virtual bool isModifier() const;
 
 	/// return the LyX symbolic name
-	virtual string getSymbolName() const;
+	virtual std::string getSymbolName() const;
 
 	/// Is this normal insertable text ? (last ditch attempt only)
 	virtual bool isText() const;
- 
+
 	/**
 	 * Return the value of the keysym into the local ISO encoding.
 	 * This converts the LyXKeySym to a 8-bit encoded character.
 	 * This relies on user to use the right encoding.
 	 */
-	virtual char getISOEncoded(string const & encoding) const;
+	virtual char getISOEncoded(std::string const & encoding) const;
+
+	/// Return a human-readable version of a key+modifier pair.
+	virtual std::string const print(key_modifier::state mod) const;
+
+	///
+	QString const qprint(key_modifier::state mod) const;
+
 	///
 	int key() const {
 		return key_;
