@@ -6,17 +6,21 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QMATHDIALOG_H
 #define QMATHDIALOG_H
 
 #include "ui/QMathDialogBase.h"
-#include "LString.h"
+#include <string>
+
+class IconPalette;
+
+namespace lyx {
+namespace frontend {
 
 class QMath;
-class IconPalette;
 
 class QMathDialog : public QMathDialogBase
 {
@@ -32,7 +36,7 @@ public slots:
 	virtual void subscriptClicked();
 	virtual void superscriptClicked();
 	virtual void equationClicked();
-	void symbol_clicked(const string &);
+	void symbol_clicked(const std::string &);
 	void insertSpace(int id);
 	void insertRoot(int id);
 	void insertStyle(int id);
@@ -53,4 +57,7 @@ private:
 	QMath * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QMATHDIALOG_H
