@@ -7,26 +7,28 @@
  * \author Edwin Leuven
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QPARAGRAPH_H
 #define QPARAGRAPH_H
 
-#include "Qt2Base.h"
-#include <vector>
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlParagraph;
 class QParagraphDialog;
 
 
 class QParagraph
-	: public Qt2CB<ControlParagraph, Qt2DB<QParagraphDialog> >
+	: public QController<ControlParagraph, QView<QParagraphDialog> >
 {
 public:
 	friend class QParagraphDialog;
 
-	QParagraph();
+	QParagraph(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -34,8 +36,9 @@ private:
 	virtual void update_contents();
 	/// build the dialog
 	virtual void build_dialog();
-
-	std::vector<string> units_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QPARAGRAPH_H
