@@ -6,29 +6,33 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QPREFS_H
 #define QPREFS_H
 
-#include "converter.h"
-
-#include "Qt2Base.h"
-#include "ControlPrefs.h"
-
+#include "QDialogView.h"
 #include <vector>
 
+class Converters;
+class Formats;
+class Movers;
+
+namespace lyx {
+namespace frontend {
+
 class QPrefsDialog;
+class ControlPrefs;
 
 class QPrefs
-	: public Qt2CB<ControlPrefs, Qt2DB<QPrefsDialog> >
+	: public QController<ControlPrefs, QView<QPrefsDialog> >
 {
 public:
 
 	friend class QPrefsDialog;
 
-	QPrefs();
+	QPrefs(Dialog &);
 
 private:
 	/// Apply changes
@@ -40,14 +44,15 @@ private:
 	/// build the dialog
 	virtual void build_dialog();
 
+	Converters & converters();
+	Formats & formats();
+	Movers & movers();
+
 	/// languages
-	std::vector<string> lang_;
-
-	/// converters
-	Converters converters_;
-
-	/// formats
-	Formats formats_;
+	std::vector<std::string> lang_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QPREFS_H
