@@ -7,26 +7,29 @@
  * \author John Levon
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QPRINT_H
 #define QPRINT_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlPrint;
 class QLPrintDialog;
 
 ///
 class QPrint
-	: public Qt2CB<ControlPrint, Qt2DB<QLPrintDialog> >
+	: public QController<ControlPrint, QView<QLPrintDialog> >
 {
 public:
 	///
 	friend class QLPrintDialog;
 	///
-	QPrint();
+	QPrint(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -36,4 +39,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QPRINT_H
