@@ -6,27 +6,30 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QREF_H
 #define QREF_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
 #include <vector>
-#include "LString.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlRef;
 class QRefDialog;
 
 
 class QRef
-	: public Qt2CB<ControlRef, Qt2DB<QRefDialog> >
+	: public QController<ControlRef, QView<QRefDialog> >
 {
 public:
 	friend class QRefDialog;
 
-	QRef();
+	QRef(Dialog &);
 protected:
 	virtual bool isValid();
 private:
@@ -64,8 +67,14 @@ private:
 	/// at a reference ?
 	bool at_ref_;
 
+	/// store the buffer settings
+	int restored_buffer_;
+
 	/// the references
-	std::vector<string> refs_;
+	std::vector<std::string> refs_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QREF_H
