@@ -7,35 +7,41 @@
  * \author Kalle Dalheimer
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QREFDIALOG_H
 #define QREFDIALOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ui/QRefDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QRef;
 
 class QRefDialog : public QRefDialogBase {
 	Q_OBJECT
 public:
 	QRefDialog(QRef * form);
+
+	virtual void show();
+
 public slots:
 	void changed_adaptor();
 	void gotoClicked();
-	void refHighlighted(QString const &);
-	void refSelected(QString const &);
+	void refHighlighted(const QString &);
+	void refSelected(const QString &);
 	void sortToggled(bool);
 	void updateClicked();
+
 protected:
 	void closeEvent(QCloseEvent * e);
 private:
 	QRef * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QREFDIALOG_H
