@@ -6,19 +6,23 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSEARCHDIALOG_H
 #define QSEARCHDIALOG_H
 
 #include "ui/QSearchDialogBase.h"
-#include "LString.h"
+#include <string>
 
-class QSearch;
 class QCloseEvent;
 class QComboBox;
 
+namespace lyx {
+namespace frontend {
+
+class QSearch;
+
 class QSearchDialog : public QSearchDialogBase {
 	Q_OBJECT
 public:
@@ -35,9 +39,12 @@ protected:
 
 private:
 	// add a string to the combo if needed
-	void remember(string const & find, QComboBox & combo);
+	void remember(std::string const & find, QComboBox & combo);
 
 	QSearch * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSEARCHDIALOG_H
