@@ -4,36 +4,36 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Juergen Spitzmueller
+ * \author Jrgen Spitzmller
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSENDTO_H
 #define QSENDTO_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-#include "Qt2Base.h"
+#include "QDialogView.h"
 
 #include <vector>
 
+class Format;
+
+namespace lyx {
+namespace frontend {
+
 class ControlSendto;
 class QSendtoDialog;
-class Format;
 
 /** This class provides a Qt implementation of the Custom Export Dialog.
  */
 class QSendto
-	: public Qt2CB<ControlSendto, Qt2DB<QSendtoDialog> >
+	: public QController<ControlSendto, QView<QSendtoDialog> >
 {
 public:
 	///
 	friend class QSendtoDialog;
 	///
-	QSendto();
+	QSendto(Dialog &);
 protected:
 	virtual bool isValid();
 private:
@@ -47,4 +47,7 @@ private:
 	std::vector<Format const *> all_formats_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSENDTO_H
