@@ -4,20 +4,19 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Juergen Spitzmueller
+ * \author Jrgen Spitzmller
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSENDTODIALOG_H
 #define QSENDTODIALOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ui/QSendtoDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QSendto;
 
 class QSendtoDialog : public QSendtoDialogBase {
@@ -34,4 +33,7 @@ private:
 	QSendto * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSENDTODIALOG_H
