@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSHOWFILEDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QShowFileDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QShowFile;
 
 class QShowFileDialog : public QShowFileDialogBase {
@@ -26,4 +29,7 @@ private:
 	QShowFile * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSHOWFILEDIALOG_H
