@@ -7,25 +7,28 @@
  * \author John Levon
  * \author Kalle Dalheimer
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSPELLCHECKER_H
 #define QSPELLCHECKER_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlSpellchecker;
 class QSpellcheckerDialog;
 
 
 class QSpellchecker
-	: public Qt2CB<ControlSpellchecker, Qt2DB<QSpellcheckerDialog> >
+	: public QController<ControlSpellchecker, QView<QSpellcheckerDialog> >
 {
 public:
 	friend class QSpellcheckerDialog;
 
-	QSpellchecker();
+	QSpellchecker(Dialog &);
 
 	/// update from controller
 	void partialUpdate(int id);
@@ -37,10 +40,13 @@ private:
 
 	/// Apply changes
 	virtual void apply() {}
-	/// not needed
-	virtual void update_contents() {}
+	///
+	virtual void update_contents();
 	/// build the dialog
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSPELLCHECKER_H
