@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QSPELLCHECKERDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QSpellcheckerDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QSpellchecker;
 
 class QSpellcheckerDialog : public QSpellcheckerDialogBase {
@@ -22,7 +25,7 @@ public:
 	QSpellcheckerDialog(QSpellchecker * form);
 public slots:
 	virtual void suggestionChanged(const QString &);
- 
+
 protected slots:
 	virtual void acceptClicked();
 	virtual void addClicked();
@@ -38,4 +41,7 @@ private:
 	QSpellchecker * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QSPELLCHECKERDIALOG_H
