@@ -6,28 +6,31 @@
  *
  * \author John Levon
  * \author Kalle Dalheimer
- * \author Juergen Spitzmueller
- * \author Herbert Voss
+ * \author Jrgen Spitzmller
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTABULAR_H
 #define QTABULAR_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlTabular;
 class QTabularDialog;
 
 
 class QTabular :
-	public Qt2CB<ControlTabular, Qt2DB<QTabularDialog> >
+	public QController<ControlTabular, QView<QTabularDialog> >
 {
 public:
 	friend class QTabularDialog;
 
-	QTabular();
+	QTabular(Dialog &);
 
 protected:
 	virtual bool isValid();
@@ -45,4 +48,7 @@ private:
 	virtual void closeGUI();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTABULAR_H
