@@ -6,27 +6,29 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTABULARCREATE_H
 #define QTABULARCREATE_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlTabularCreate;
 class QTabularCreateDialog;
 
-
 ///
 class QTabularCreate
-	: public Qt2CB<ControlTabularCreate, Qt2DB<QTabularCreateDialog> >
+	: public QController<ControlTabularCreate, QView<QTabularCreateDialog> >
 {
 public:
 	///
 	friend class QTabularCreateDialog;
 	///
-	QTabularCreate();
+	QTabularCreate(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -36,4 +38,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTABULARCREATE_H
