@@ -7,18 +7,17 @@
  * \author John Levon
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTABULARCREATEDIALOG_H
 #define QTABULARCREATEDIALOG_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "ui/QTabularCreateDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QTabularCreate;
 
 class QTabularCreateDialog : public QTabularCreateDialogBase {
@@ -32,4 +31,7 @@ private:
 	QTabularCreate * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTABULARCREATEDIALOG_H
