@@ -5,10 +5,10 @@
  * Licence details can be found in the file COPYING.
  *
  * \author John Levon
- * \author Juergen Spitzmueller
- * \author Herbert Voss
+ * \author Jrgen Spitzmller
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTABULARDIALOG_H
@@ -16,6 +16,9 @@
 
 #include "ui/QTabularDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QTabular;
 
 class QTabularDialog : public QTabularDialogBase {
@@ -27,10 +30,6 @@ protected slots:
 	virtual void change_adaptor();
 
 	virtual void close_clicked();
-	virtual void columnAppend_clicked();
-	virtual void rowAppend_clicked();
-	virtual void columnDelete_clicked();
-	virtual void rowDelete_clicked();
 	virtual void borderSet_clicked();
 	virtual void borderUnset_clicked();
 	virtual void leftBorder_changed();
@@ -38,13 +37,13 @@ protected slots:
 	virtual void topBorder_changed();
 	virtual void bottomBorder_changed();
 	virtual void multicolumn_clicked();
-	virtual void rotateTabular_checked(int state);
-	virtual void rotateCell_checked(int state);
+	virtual void rotateTabular();
+	virtual void rotateCell();
 	virtual void hAlign_changed(int align);
 	virtual void vAlign_changed(int align);
 	virtual void specialAlignment_changed();
 	virtual void width_changed();
-	virtual void longTabular_changed(int state);
+	virtual void longTabular();
 	virtual void ltNewpage_clicked();
 	virtual void ltHeaderStatus_clicked();
 	virtual void ltHeaderBorderAbove_clicked();
@@ -68,4 +67,7 @@ private:
 	QTabular * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTABULARDIALOG_H
