@@ -6,29 +6,31 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTEXINFO_H
 #define QTEXINFO_H
 
-#include "Qt2Base.h"
-
+#include "QDialogView.h"
 #include "ControlTexinfo.h"
 
+#include <map>
 #include <vector>
 
+namespace lyx {
+namespace frontend {
+
 class QTexinfoDialog;
 
 ///
 class QTexinfo
-	: public Qt2CB<ControlTexinfo, Qt2DB<QTexinfoDialog> >
-{
+	 : public QController<ControlTexinfo, QView<QTexinfoDialog> > {
 public:
 	///
 	friend class QTexinfoDialog;
 	///
-	QTexinfo();
+	QTexinfo(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply() {}
@@ -45,11 +47,11 @@ private:
 	///
 	ControlTexinfo::texFileSuffix activeStyle;
 	///
-	std::vector<string> cls_;
-	///
-	std::vector<string> sty_;
-	///
-	std::vector<string> bst_;
+	typedef std::vector<std::string> ContentsType;
+	std::map<ControlTexinfo::texFileSuffix, ContentsType> texdata_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTEXINFO_H
