@@ -6,7 +6,7 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTEXINFODIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QTexinfoDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QTexinfo;
 
 class QTexinfoDialog : public QTexinfoDialogBase {
@@ -32,4 +35,7 @@ private:
 	QTexinfo * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTEXINFODIALOG_H
