@@ -6,26 +6,29 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTHESAURUS_H
 #define QTHESAURUS_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlThesaurus;
 class QThesaurusDialog;
 
 ///
 class QThesaurus
-	: public Qt2CB<ControlThesaurus, Qt2DB<QThesaurusDialog> >
+	: public QController<ControlThesaurus, QView<QThesaurusDialog> >
 {
 public:
 	///
 	friend class QThesaurusDialog;
 	///
-	QThesaurus();
+	QThesaurus(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply() {}
@@ -38,4 +41,7 @@ private:
 	void replace();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTHESAURUS_H
