@@ -7,29 +7,28 @@
  * \author John Levon
  * \author Kalle Dalheimer
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTOC_H
 #define QTOC_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-#include "Qt2Base.h"
+#include "QDialogView.h"
 #include "toc.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlToc;
 class QTocDialog;
 
 class QToc :
-	public Qt2CB<ControlToc, Qt2DB<QTocDialog> >
+	public QController<ControlToc, QView<QTocDialog> >
 {
 public:
 	friend class QTocDialog;
 
-	QToc();
+	QToc(Dialog &);
 private:
 	/// update the listview
 	void updateToc(int newdepth);
@@ -38,7 +37,7 @@ private:
 	void updateType();
 
 	/// select an entry
-	void select(string const & text);
+	void select(std::string const & text);
 
 	/// set the depth
 	void set_depth(int depth);
@@ -52,10 +51,13 @@ private:
 	virtual void build_dialog();
 
 	/// the toc list
-	toc::Toc toclist;
+	lyx::toc::Toc toclist;
 
 	/// depth of list shown
 	int depth_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTOC_H
