@@ -6,24 +6,26 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QURL_H
 #define QURL_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
 
-class ControlUrl;
+namespace lyx {
+namespace frontend {
+
+class ControlCommand;
 class QURLDialog;
 
-
 class QURL :
-	public Qt2CB<ControlUrl, Qt2DB<QURLDialog> >
+	public QController<ControlCommand, QView<QURLDialog> >
 {
 public:
 	friend class QURLDialog;
-	QURL();
+	QURL(Dialog &);
 protected:
 	virtual bool isValid();
 private:
@@ -35,4 +37,7 @@ private:
 	virtual void update_contents();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QURL_H
