@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QURLDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QURLDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QURL;
 
 class QURLDialog : public QURLDialogBase {
@@ -31,4 +34,7 @@ private:
 	QURL * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QURLDIALOG_H
