@@ -4,27 +4,28 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Juergen Spitzmueller
+ * \author Jrgen Spitzmller
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QWRAP_H
 #define QWRAP_H
 
-#include "Qt2Base.h"
+#include "QDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlWrap;
 class QWrapDialog;
 
 
-class QWrap
-	: public Qt2CB<ControlWrap, Qt2DB<QWrapDialog> >
-{
+class QWrap : public QController<ControlWrap, QView<QWrapDialog> > {
 public:
 	friend class QWrapDialog;
 
-	QWrap();
+	QWrap(Dialog &);
 private:
 	/// Apply changes
 	virtual void apply();
@@ -34,4 +35,7 @@ private:
 	virtual void build_dialog();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QWRAP_H
