@@ -4,9 +4,9 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Juergen Spitzmueller
+ * \author Jrgen Spitzmller
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QWRAPDIALOG_H
@@ -14,6 +14,9 @@
 
 #include "ui/QWrapDialogBase.h"
 
+namespace lyx {
+namespace frontend {
+
 class QWrap;
 
 class QWrapDialog : public QWrapDialogBase {
@@ -28,4 +31,7 @@ private:
 	QWrap * form_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QWRAPDIALOG_H
