@@ -6,7 +6,7 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 /* Qt has a messy namespace which conflicts with 'emit' in
@@ -15,4 +15,3 @@
 
 #undef emit
 #undef signals
-#include "frontends/LyXView.h"
