@@ -7,17 +7,25 @@
  * \author Lars Gullik Bjornes
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef QTVIEW_H
 #define QTVIEW_H
 
+// Must be here because of moc.
+#include <config.h>
+
 #include "frontends/LyXView.h"
 
 #include <qmainwindow.h>
 #include <qtimer.h>
 
+class FuncRequest;
+
+namespace lyx {
+namespace frontend {
+
 class QCommandBuffer;
 
 /**
@@ -36,17 +44,25 @@ public:
 	/// show - display the top-level window
 	void show();
 
-	/// start modal operation
-	virtual void prohibitInput() const;
-	/// end modal operation
-	virtual void allowInput() const;
+	/// show busy cursor
+	virtual void busy(bool) const;
 
 	/// display a status message
-	virtual void message(string const & str);
-public slots:
-	/// menu item has been selected
-	void activated(int id);
+	virtual void message(std::string const & str);
 
+	/// clear status message
+	virtual void clearMessage();
+
+	/// add the command buffer
+	void addCommandBuffer(QWidget * parent);
+
+	/// menu item has been selected
+	void activated(FuncRequest const &);
+
+	// returns true if this view has the focus.
+	virtual bool hasFocus() const;
+
+public slots:
 	/// idle timeout
 	void update_view_state_qt();
 protected:
@@ -64,13 +80,15 @@ private:
 	 * @param t main window title
 	 * @param it iconified (short) title
 	 */
-	virtual void setWindowTitle(string const & t, string const & it);
+	virtual void setWindowTitle(std::string const & t, std::string const & it);
 
-	/// idle timer
-	QTimer idle_timer_;
+	QTimer statusbar_timer_;
 
 	/// command buffer
 	QCommandBuffer * commandbuffer_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // QTVIEW_H
