@@ -6,13 +6,12 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef EMPTYTABLE_H
 #define EMPTYTABLE_H
 
-#include <qpainter.h>
 #include "qttableview.h"
 
 /**
