@@ -6,12 +6,13 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef LENGTHCOMBO_H
 #define LENGTHCOMBO_H
 
+
 #include <qcombobox.h>
 
 #include "vspace.h"
@@ -24,12 +25,16 @@ class LengthCombo : public QComboBox {
 public:
 	LengthCombo(QWidget * parent, char * name);
 
-	/// set the current item
+	/// set the current item from unit
 	virtual void setCurrentItem(LyXLength::UNIT unit);
+	/// set the current item from int
+	virtual void setCurrentItem(int item);
 	/// get the current item
 	LyXLength::UNIT currentLengthItem() const;
 	/// enable the widget
 	virtual void setEnabled(bool b);
+	/// use the %-items?
+	virtual void noPercents();
 
 protected slots:
 	virtual void has_activated(int index);
