@@ -1,3 +1,4 @@
+// -*- C++ -*-
 /**
  * \file qcoloritem.h
  * This file is part of LyX, the document processor.
@@ -5,9 +6,12 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
+#ifndef QT_QCOLORITEM_H
+#define QT_QCOLORITEM_H
+
 #include <qlistbox.h>
 #include <qcolor.h>
 
@@ -46,3 +50,5 @@ private:
 
 	QString text_;
 };
+
+#endif
