@@ -1,24 +1,24 @@
 // -*- C++ -*-
 /**
- * \file QSetBorder.h
+ * \file qsetborder.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Edwin Leuven
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 #ifndef QSETBORDER_H
 #define QSETBORDER_H
 
 #include <qwidget.h>
 #include <qpixmap.h>
-#include <qcolor.h>
 
+class QColor;
 class QMouseEvent;
-class QResizeEvent;
 class QPaintEvent;
+class QResizeEvent;
 
 class QSetBorder : public QWidget
 {
@@ -63,7 +63,8 @@ private:
 	void drawTop(bool);
 	void drawBottom(bool);
 
-	struct Border {
+	class Border {
+	public:
 		Border() : set(true), enabled(true) {}
 		bool set;
 		bool enabled;
