@@ -7,16 +7,19 @@
  * \author Asger Alstrup
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FONTINFO_H
 #define FONTINFO_H
 
-#include "LString.h"
-
 #include <boost/scoped_array.hpp>
 
+#include <string>
+
+namespace lyx {
+namespace frontend {
+
 /** This class manages a font.
     The idea is to create a FontInfo object with a font name pattern with a
     wildcard at the size field. Then this object can host request for font-
@@ -31,7 +34,7 @@ public:
 	FontInfo() { init(); }
 
 	///
-	explicit FontInfo(string const & pat)
+	explicit FontInfo(std::string const & pat)
 		: pattern(pat) { init(); }
 
 	/// Does any font match our pattern?
@@ -47,23 +50,23 @@ public:
 	}
 
 	/// Get existing pattern
-	string const & getPattern() const { return pattern; }
+	std::string const & getPattern() const { return pattern; }
 
 	/// Set new pattern
-	void setPattern(string const & pat);
+	void setPattern(std::string const & pat);
 
 	/** Return full name of font close to this size.
 	  If impossible, result is the empty string */
-	string const getFontname(int size);
+	std::string const getFontname(int size);
 private:
 	/// Font pattern (with wildcard for size)
-	string pattern;
+	std::string pattern;
 
 	/// Available size list
 	boost::scoped_array<int> sizes;
 
 	/// Corresponding name list
-	boost::scoped_array<string> strings;
+	boost::scoped_array<std::string> strings;
 
 	/// Number of matches
 	int matches;
@@ -84,7 +87,10 @@ private:
 	void query();
 
 	/// Build newly sized font string
-	string const resize(string const &, int size) const;
+	std::string const resize(std::string const &, int size) const;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FONTINFO_H
