@@ -7,24 +7,27 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMBIBITEM_H
 #define FORMBIBITEM_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlBibitem;
+namespace lyx {
+namespace frontend {
+
+class ControlCommand;
 struct FD_bibitem;
 
 /**
  * For bibliography entry editing
  */
-class FormBibitem : public FormCB<ControlBibitem, FormDB<FD_bibitem> > {
+class FormBibitem : public FormController<ControlCommand, FormView<FD_bibitem> > {
 public:
 	///
-	FormBibitem();
+	FormBibitem(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -36,4 +39,7 @@ private:
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMBIBITEM_H
