@@ -7,13 +7,16 @@
  * \author Angus Leeming
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMBIBTEX_H
 #define FORMBIBTEX_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlBibtex;
 struct FD_bibtex;
@@ -21,10 +24,10 @@ struct FD_bibtex;
 /**
  * For bibtex database setting
  */
-class FormBibtex : public FormCB<ControlBibtex, FormDB<FD_bibtex> > {
+class FormBibtex : public FormController<ControlBibtex, FormView<FD_bibtex> > {
 public:
 	///
-	FormBibtex();
+	FormBibtex(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -36,4 +39,7 @@ private:
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMBIBTEX_H
