@@ -7,27 +7,34 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMBROWSER_H
 #define FORMBROWSER_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
+
+struct FD_browser;
 
 /**
  * This class provides an XForms implementation of a read only
  * text browser.
  */
-struct FD_browser;
 
-class FormBrowser : public FormDB<FD_browser> {
+class FormBrowser : public FormView<FD_browser> {
 public:
 	///
-	FormBrowser(string const &, bool allowResize = true);
+	FormBrowser(Dialog &, std::string const &, bool allowResize = true);
 private:
 	/// Build the dialog.
 	virtual void build();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMBROWSER_H
