@@ -1,18 +1,21 @@
 // -*- C++ -*-
 /**
- * \file xforms/FormERT.h
+ * \file FormERT.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Jrgen Vigna
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMERT_H
 #define FORMERT_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlERT;
 struct FD_ert;
@@ -20,11 +23,10 @@ struct FD_ert;
 /** This class provides an XForms implementation of the ERT
     Dialog.
  */
-class FormERT
-	: public FormCB<ControlERT, FormDB<FD_ert> > {
+class FormERT : public FormController<ControlERT, FormView<FD_ert> > {
 public:
 	///
-	FormERT();
+	FormERT(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -34,4 +36,7 @@ private:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMERT_H
