@@ -6,25 +6,28 @@
  *
  * \author Lars Gullik Bjnnes
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMFLOAT_H
 #define FORMFLOAT_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "RadioButtonGroup.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlFloat;
 struct FD_float;
 
 /** This class provides an XForms implementation of the Float
     Dialog.
  */
-class FormFloat : public FormCB<ControlFloat, FormDB<FD_float> > {
+class FormFloat : public FormController<ControlFloat, FormView<FD_float> > {
 public:
 	///
-	FormFloat();
+	FormFloat(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -39,4 +42,7 @@ private:
 	RadioButtonGroup placement_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMFLOAT_H
