@@ -5,20 +5,22 @@
  * Licence details can be found in the file COPYING.
  *
  * \author Baruch Even
- * \author Herbert Voss
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMGRAPHICS_H
 #define FORMGRAPHICS_H
 
-#include "FormBase.h"
-
+#include "FormDialogView.h"
 #include <boost/scoped_ptr.hpp>
-
 #include <vector>
 
+namespace lyx {
+namespace frontend {
+
+class CheckedPath;
 class ControlGraphics;
 struct FD_graphics;
 struct FD_graphics_file;
@@ -27,10 +29,11 @@ struct FD_graphics_extra;
 
 /** This class provides an XForms implementation of the Graphics Dialog.
  */
-class FormGraphics : public FormCB<ControlGraphics, FormDB<FD_graphics> > {
+class FormGraphics
+	: public FormController<ControlGraphics, FormView<FD_graphics> > {
 public:
 	///
-	FormGraphics();
+	FormGraphics(Dialog &);
 private:
 
 	/** Redraw the form (on receipt of a Signal indicating, for example,
@@ -43,10 +46,13 @@ private:
 	/// Update dialog before/whilst showing it.
 	virtual void update();
 	/// Update the BoundingBox info.
-	void updateBB(string const & filename, string const & bb_inset);
+	void updateBB(std::string const & filename, std::string const & bb_inset);
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 
+	// Accessor to checker owned by the button controller.
+	CheckedPath * file_checker_;
+
 	/// Real GUI implementation.
 	boost::scoped_ptr<FD_graphics_file> file_;
 	///
@@ -55,7 +61,10 @@ private:
 	boost::scoped_ptr<FD_graphics_extra> extra_;
 
 	/// Store the LaTeX names for the rotation origins.
-	std::vector<string> origins_;
+	std::vector<std::string> origins_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif  // FORMGRAPHICS_H
