@@ -8,22 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 #ifndef FORMINCLUDE_H
 #define FORMINCLUDE_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+#include "RadioButtonGroup.h"
 
+namespace lyx {
+namespace frontend {
+
+class CheckedPath;
 class ControlInclude;
 struct FD_include;
 
 /** This class provides an XForms implementation of the Include Dialog.
  */
-class FormInclude : public FormCB<ControlInclude, FormDB<FD_include> > {
+class FormInclude
+	: public FormController<ControlInclude, FormView<FD_include> > {
 public:
 	///
-	FormInclude();
+	FormInclude(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -33,6 +39,15 @@ private:
 	virtual void update();
 	/// Filter the inputs on callback from xforms
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
+
+	// Accessor to checker owned by the button controller.
+	CheckedPath * file_checker_;
+
+	/// include type
+	RadioButtonGroup type_;
 };
 
-#endif
+} // namespace frontend
+} // namespace lyx
+
+#endif // FORMINCLUDE_H
