@@ -1,12 +1,12 @@
 // -*- C++ -*-
 /**
- * FormLog.h
+ * \file FormLog.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMLOG_H
@@ -14,16 +14,19 @@
 
 #include "FormBrowser.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlLog;
 
 /**
  * This class provides an XForms implementation of the LaTeX log dialog
  * for viewing the last LaTeX log file.
  */
-class FormLog : public FormCB<ControlLog, FormBrowser> {
+class FormLog : public FormController<ControlLog, FormBrowser> {
 public:
 	///
-	FormLog();
+	FormLog(Dialog &);
 
 	// Functions accessible to the Controller.
 
@@ -33,4 +36,7 @@ public:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMLOG_H
