@@ -8,28 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSDELIM_H
 #define FORM_MATHSDELIM_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
+#include "FormDialogView.h"
 
-#include "FormBase.h"
+namespace lyx {
+namespace frontend {
 
-class ControlMathSub;
+class ControlMath;
 struct FD_maths_delim;
 
 /**
  * This class provides an XForms implementation of the maths delim.
  */
-class FormMathsDelim : public FormCB<ControlMathSub, FormDB<FD_maths_delim> > {
+class FormMathsDelim
+	: public FormController<ControlMath, FormView<FD_maths_delim> > {
 public:
 	///
-	FormMathsDelim();
+	FormMathsDelim(Dialog &);
 
 private:
 	///
@@ -42,4 +42,7 @@ private:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSDELIM_H
