@@ -8,25 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSMATRIX_H
 #define FORM_MATHSMATRIX_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlMathSub;
+namespace lyx {
+namespace frontend {
+
+class ControlMath;
 struct FD_maths_matrix;
 
 /**
  * This class provides an XForms implementation of the maths matrix.
  */
-class FormMathsMatrix : public FormCB<ControlMathSub, FormDB<FD_maths_matrix> >
-{
+class FormMathsMatrix
+	: public FormController<ControlMath, FormView<FD_maths_matrix> > {
 public:
 	///
-	FormMathsMatrix();
+	FormMathsMatrix(Dialog &);
 	///
 	int AlignFilter(char const *, int);
 
@@ -41,4 +44,7 @@ private:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSMATRIX_H
