@@ -8,25 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSPANEL_H
 #define FORM_MATHSPANEL_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlMath;
 struct FD_maths_panel;
-class FormMathsBitmap;
 
 /**
  * This class provides an XForms implementation of the maths panel.
  */
-class FormMathsPanel : public FormCB<ControlMath, FormDB<FD_maths_panel> > {
+class FormMathsPanel
+	: public FormController<ControlMath, FormView<FD_maths_panel> > {
 public:
 	///
-	FormMathsPanel();
+	FormMathsPanel(Dialog &);
 
 private:
 	/// Not needed.
@@ -38,12 +41,9 @@ private:
 	virtual void build();
 	///
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
-
-	/** Add a bitmap dialog to the store of all daughters_ and
-	 *  return a pointer to the dialog, so that bitmaps can be added to it.
-	 */
-	FormMathsBitmap * addDaughter(void * button, string const & title,
-				      char const * const * data, int size);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSPANEL_H
