@@ -8,24 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSSPACE_H
 #define FORM_MATHSSPACE_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlMathSub;
+namespace lyx {
+namespace frontend {
+
+class ControlMath;
 struct FD_maths_space;
 
 /**
  * This class provides an XForms implementation of the maths space.
  */
-class FormMathsSpace : public FormCB<ControlMathSub, FormDB<FD_maths_space> > {
+class FormMathsSpace
+	: public FormController<ControlMath, FormView<FD_maths_space> > {
 public:
 	///
-	FormMathsSpace();
+	FormMathsSpace(Dialog &);
 
 private:
 	///
@@ -41,4 +45,7 @@ private:
 	int space_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSSPACE_H
