@@ -8,24 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSSTYLE_H
 #define FORM_MATHSSTYLE_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlMathSub;
+namespace lyx {
+namespace frontend {
+
+class ControlMath;
 struct FD_maths_style;
 
 /**
  * This class provides an XForms implementation of the maths style.
  */
-class FormMathsStyle : public FormCB<ControlMathSub, FormDB<FD_maths_style> > {
+class FormMathsStyle
+	: public FormController<ControlMath, FormView<FD_maths_style> > {
 public:
 	///
-	FormMathsStyle();
+	FormMathsStyle(Dialog &);
 
 private:
 	///
@@ -41,4 +45,7 @@ private:
 	int style_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSSTYLE_H
