@@ -6,25 +6,28 @@
  *
  * \author Jrgen Vigna
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_PARAGRAPH_H
 #define FORM_PARAGRAPH_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "RadioButtonGroup.h"
 
-struct FD_paragraph;
+namespace lyx {
+namespace frontend {
+
 class ControlParagraph;
+struct FD_paragraph;
 
 /** This class provides an XForms implementation of the FormParagraph dialog.
  */
 class FormParagraph
-	: public FormCB<ControlParagraph, FormDB<FD_paragraph> > {
+	: public FormController<ControlParagraph, FormView<FD_paragraph> > {
 public:
 	///
-	FormParagraph();
+	FormParagraph(Dialog &);
 private:
 	/// Build the dialog
 	virtual void build();
@@ -40,4 +43,7 @@ private:
 	RadioButtonGroup alignment_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif
