@@ -6,23 +6,27 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMPREAMBLE_H
 #define FORMPREAMBLE_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlPreamble;
 struct FD_preamble;
 
 /** This class provides an XForms implementation of the Preamble Dialog.
  */
-class FormPreamble : public FormCB<ControlPreamble, FormDB<FD_preamble> > {
+class FormPreamble
+	: public FormController<ControlPreamble, FormView<FD_preamble> > {
 public:
 	///
-	FormPreamble();
+	FormPreamble(Dialog &);
 private:
 	/// Apply from dialog
 	virtual void apply();
@@ -32,5 +36,7 @@ private:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
 
 #endif // FORMPREAMBLE_H
