@@ -1,32 +1,35 @@
 // -*- C++ -*-
 /**
- * \file xforms/FormPrint.h
- * Copyright 1999-2001 Allan Rae
+ * \file FormPrint.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Allan Rae
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMPRINT_H
 #define FORMPRINT_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "RadioButtonGroup.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlPrint;
 struct FD_print;
 
 /** This class provides an XForms implementation of the FormPrint Dialog.
     The print dialog allows users to print their documents.
  */
-class FormPrint : public FormCB<ControlPrint, FormDB<FD_print> > {
+class FormPrint
+	: public FormController<ControlPrint, FormView<FD_print> > {
 public:
 	///
-	FormPrint();
+	FormPrint(Dialog &);
 private:
 	/// Apply from dialog
 	virtual void apply();
@@ -44,4 +47,7 @@ private:
 	RadioButtonGroup all_pages_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMPRINT_H
