@@ -1,28 +1,31 @@
 // -*- C++ -*-
 /**
- * \file xforms/FormRef.h
+ * \file FormRef.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMREF_H
 #define FORMREF_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlRef;
 struct FD_ref;
 
 /** This class provides an XForms implementation of the FormRef Dialog.
  */
-class FormRef : public FormCB<ControlRef, FormDB<FD_ref> > {
+class FormRef : public FormController<ControlRef, FormView<FD_ref> > {
 public:
 	///
-	FormRef();
+	FormRef(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -34,7 +37,7 @@ private:
 	virtual void update();
 
 	///
-	void updateBrowser(std::vector<string> const &) const;
+	void updateBrowser(std::vector<std::string> const &) const;
 
 	///
 	void switch_go_button();
@@ -42,7 +45,10 @@ private:
 	///
 	bool at_ref_;
 	///
-	std::vector<string> refs_;
+	std::vector<std::string> refs_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMREF_H
