@@ -6,23 +6,27 @@
  *
  * \author Edwin Leuven
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMSEARCH_H
 #define FORMSEARCH_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
+
+namespace lyx {
+namespace frontend {
 
 class ControlSearch;
 struct FD_search;
 
 /** This class provides an XForms implementation of the FormSearch Dialog.
  */
-class FormSearch : public FormCB<ControlSearch, FormDB<FD_search> > {
+class FormSearch
+	: public FormController<ControlSearch, FormView<FD_search> > {
 public:
 	///
-	FormSearch();
+	FormSearch(Dialog &);
 private:
 	/// not needed.
 	virtual void apply() {}
@@ -35,4 +39,7 @@ private:
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMSEARCH_H
