@@ -6,25 +6,30 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMSENDTO_H
 #define FORMSENDTO_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include <vector>
 
-class ControlSendto;
 class Format;
+
+namespace lyx {
+namespace frontend {
+
+class ControlSendto;
 struct FD_sendto;
 
 /** This class provides an XForms implementation of the Custom Export Dialog.
  */
-class FormSendto : public FormCB<ControlSendto, FormDB<FD_sendto> > {
+class FormSendto
+	: public FormController<ControlSendto, FormView<FD_sendto> > {
 public:
 	///
-	FormSendto();
+	FormSendto(Dialog &);
 private:
 	/// Apply from dialog (modify or create inset)
 	virtual void apply();
@@ -38,4 +43,7 @@ private:
 	std::vector<Format const *> all_formats_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMSENDTO_H
