@@ -4,23 +4,28 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Herbert Voss
+ * \author Herbert Vo
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMTEXINFO_H
 #define FORMTEXINFO_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "ControlTexinfo.h"
+#include <map>
+
+namespace lyx {
+namespace frontend {
 
 struct FD_texinfo;
 
-class FormTexinfo : public FormCB<ControlTexinfo, FormDB<FD_texinfo> > {
+class FormTexinfo
+	: public FormController<ControlTexinfo, FormView<FD_texinfo> > {
 public:
 	///
-	FormTexinfo();
+	FormTexinfo(Dialog &);
 private:
 	/// not needed
 	virtual void apply() {}
@@ -34,6 +39,13 @@ private:
 	void updateStyles(ControlTexinfo::texFileSuffix);
 	///
 	ControlTexinfo::texFileSuffix activeStyle;
+
+	///
+	typedef std::vector<std::string> ContentsType;
+	std::map<ControlTexinfo::texFileSuffix, ContentsType> texdata_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMTEXINFO_H
