@@ -6,27 +6,27 @@
  *
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMTHESAURUS_H
 #define FORMTHESAURUS_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
+#include "FormDialogView.h"
 
-#include "FormBase.h"
+namespace lyx {
+namespace frontend {
 
 class ControlThesaurus;
 struct FD_thesaurus;
 
 /** This class provides an XForms implementation of the Thesaurus dialog.
  */
-class FormThesaurus : public FormCB<ControlThesaurus, FormDB<FD_thesaurus> > {
+class FormThesaurus
+	: public FormController<ControlThesaurus, FormView<FD_thesaurus> > {
 public:
 	///
-	FormThesaurus();
+	FormThesaurus(Dialog &);
 private:
 	/// not needed.
 	virtual void apply() {}
@@ -36,10 +36,10 @@ private:
 	virtual void update();
 
 	/// set the replace word properly
-	void setReplace(string const & templ, string const & nstr);
+	void setReplace(std::string const & templ, std::string const & nstr);
 
 	/// update browser entries
-	void updateMeanings(string const & str);
+	void updateMeanings(std::string const & str);
 
 	/// Filter the inputs
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
@@ -48,7 +48,10 @@ private:
 	int clickline_;
 
 	/// current string
-	string str_;
+	std::string str_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMTHESAURUS_H
