@@ -1,29 +1,32 @@
 // -*- C++ -*-
 /**
- * \file xforms/FormToc.h
+ * \file FormToc.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMTOC_H
 #define FORMTOC_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "toc.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlToc;
 struct FD_toc;
 
 /** This class provides an XForms implementation of the FormToc Dialog.
  */
-class FormToc : public FormCB<ControlToc, FormDB<FD_toc> > {
+class FormToc : public FormController<ControlToc, FormView<FD_toc> > {
 public:
 	///
-	FormToc();
+	FormToc(Dialog &);
 private:
 	/// not needed
 	virtual void apply() {}
@@ -43,4 +46,7 @@ private:
 	toc::Toc toc_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMTOC_H
