@@ -1,28 +1,31 @@
 // -*- C++ -*-
 /**
- * \file xforms/FormUrl.h
+ * \file FormUrl.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMURL_H
 #define FORMURL_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlUrl;
+namespace lyx {
+namespace frontend {
+
+class ControlCommand;
 struct FD_url;
 
 /** This class provides an XForms implementation of the Url Dialog.
  */
-class FormUrl : public FormCB<ControlUrl, FormDB<FD_url> > {
+class FormUrl : public FormController<ControlCommand, FormView<FD_url> > {
 public:
 	///
-	FormUrl();
+	FormUrl(Dialog &);
 private:
 	/// Apply from dialog (modify or create inset)
 	virtual void apply();
@@ -32,4 +35,7 @@ private:
 	virtual void update();
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMURL_H
