@@ -6,19 +6,18 @@
  *
  * \author Dekel Tsur
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMWRAP_H
 #define FORMWRAP_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-#include "FormBase.h"
+#include "FormDialogView.h"
 #include "RadioButtonGroup.h"
 
+namespace lyx {
+namespace frontend {
+
 class ControlWrap;
 struct FD_wrap;
 
@@ -26,10 +25,10 @@ struct FD_wrap;
     Dialog.
  */
 class FormWrap
-	: public FormCB<ControlWrap, FormDB<FD_wrap> > {
+	: public FormController<ControlWrap, FormView<FD_wrap> > {
 public:
 	///
-	FormWrap();
+	FormWrap(Dialog &);
 private:
 	/// Set the Params variable for the Controller.
 	virtual void apply();
@@ -42,4 +41,7 @@ private:
 	RadioButtonGroup placement_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // FORMWRAP_H
