@@ -1,14 +1,13 @@
 // -*- C++ -*-
 /**
  * \file RadioButtonGroup.h
- * Copyright 2000 Baruch Even
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Baruch Even
  * \author Rob Lahaye
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 
@@ -20,6 +19,9 @@
 #include <utility>
 #include "forms_fwd.h"
 
+namespace lyx {
+namespace frontend {
+
 /** This class simplifies interaction with a group of radio buttons:
  *  one, and only one, can be selected.
  *  The idea is that you register a bunch of radio buttons with
@@ -31,19 +33,22 @@
  */
 class RadioButtonGroup {
 public:
-	///
-	typedef lyx::size_type size_type;
 
 	/// Register a radio button with its corresponding value.
 	void init(FL_OBJECT * ob, size_type value);
 
 	// Set a single active button.
-	void set(size_type value);
-	void set(FL_OBJECT * ob);
+	void set(size_type value) const;
+	void set(FL_OBJECT * ob) const;
+
+	// None of the radiobuttons are set.
+	void unset() const;
 
 	// Get the active button's value.
 	size_type get() const;
 
+	void setEnabled(bool enabled);
+
 private:
 	///
 	typedef std::pair<FL_OBJECT *, size_type> ButtonValuePair;
@@ -53,4 +58,7 @@ private:
 	ButtonValueMap map;
 };
 
-#endif
+} // namespace frontend
+} // namespace lyx
+
+#endif // RADIOBUTTONGROUP_H
