@@ -6,17 +6,25 @@
  *
  * \author unknown
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef LyXView_H
 #define LyXView_H
 
+#include "LayoutEngine.h"
 #include "forms_fwd.h"
 
 #include "frontends/LyXView.h"
 #include <X11/Xlib.h> // for Pixmap
 
+#include <boost/signal.hpp>
+
+#include <map>
+
+namespace lyx {
+namespace frontend {
+
 class XMiniBuffer;
 
 /**
@@ -26,33 +34,53 @@ class XMiniBuffer;
  */
 class XFormsView : public LyXView {
 public:
+	enum Position {
+		Top,
+		Bottom,
+		Left,
+		Right,
+		Center
+	};
+
 	/// create a main window of the given dimensions
 	XFormsView(int w, int h);
 
 	~XFormsView();
 
+	/// Accessor to the appropriate layout Box.
+	boost::shared_ptr<Box> getBox(Position pos) const;
+
 	/**
 	 * show - display the top-level window
 	 * @param xpos requested x position (or 0)
 	 * @param xpos requested y position (or 0)
 	 * @param title window title
 	 */
-	void show(int xpos, int ypos, string const & t = string("LyX"));
+	void show(int xpos, int ypos, std::string const & t = std::string("LyX"));
 
 	/// get the xforms main form
 	FL_FORM * getForm() const;
 	/// redraw the main form.
 	virtual void redraw();
-	///
-	virtual void prohibitInput() const;
-	///
-	virtual void allowInput() const;
+	/// show busy cursor
+	virtual void busy(bool) const;
 
 	/// callback for close event from window manager
 	static int atCloseMainFormCB(FL_FORM *, void *);
 
 	/// display a status message
-	virtual void message(string const & str);
+	virtual void message(std::string const & str);
+
+	/// clear back to normal status message
+	virtual void clearMessage();
+
+	///
+	void updateMetrics(bool resize_form = false);
+	///
+	boost::signal<void()> metricsUpdated;
+
+	// returns true if this view has the focus.
+	virtual bool hasFocus() const;
 
 private:
 	/**
@@ -60,13 +88,19 @@ private:
 	 * @param t main window title
 	 * @param it iconified (short) title
 	 */
-	virtual void setWindowTitle(string const & t, string const & it);
+	virtual void setWindowTitle(std::string const & t, std::string const & it);
 
 	/// update the minibuffer state message
 	void show_view_state();
 
-	/// makes the main form.
-	void create_form_form_main(int width, int height);
+	/// The top-most box of the layout engine containing all other boxes.
+	Box window_;
+
+	typedef std::map<Position, boost::shared_ptr<Box> > BoxMap;
+
+	// Accessors to the various Boxes.
+	BoxMap box_map_;
+
 	/// the minibuffer
 	boost::scoped_ptr<XMiniBuffer> minibuffer_;
 	///
@@ -83,4 +117,8 @@ private:
 	///
 	Pixmap icon_mask_;
 };
+
+} // namespace frontend
+} // namespace lyx
+
 #endif
