@@ -7,21 +7,21 @@
  * \author unknown
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef XPAINTER_H
 #define XPAINTER_H
 
-#include <config.h>
-
 #include "frontends/Painter.h"
-#include "LString.h"
 
 #include <X11/Xlib.h>
 
-
 class LyXFont;
+
+namespace lyx {
+namespace frontend {
+
 class XWorkArea;
 
 /**
@@ -37,10 +37,10 @@ public:
 	virtual int paperHeight() const;
 
 	/// draw a line from point to point
-	virtual Painter & line(
+	virtual void line(
 		int x1, int y1,
 		int x2, int y2,
-		LColor::color = LColor::foreground,
+		LColor_color,
 		line_style = line_solid,
 		line_width = line_thin);
 
@@ -50,69 +50,69 @@ public:
 	 * @param yp array of points' y co-ords
 	 * @param np size of the points array
 	 */
-	virtual Painter & lines(
+	virtual void lines(
 		int const * xp,
 		int const * yp,
 		int np,
-		LColor::color = LColor::foreground,
+		LColor_color,
 		line_style = line_solid,
 		line_width = line_thin);
 
 	/// draw a rectangle
-	virtual Painter & rectangle(
+	virtual void rectangle(
 		int x, int y,
 		int w, int h,
-		LColor::color = LColor::foreground,
+		LColor_color,
 		line_style = line_solid,
 		line_width = line_thin);
 
 	/// draw a filled rectangle
-	virtual Painter & fillRectangle(
+	virtual void fillRectangle(
 		int x, int y,
 		int w, int h,
-		LColor::color);
+		LColor_color);
 
 	/// draw a filled (irregular) polygon
-	virtual Painter & fillPolygon(
+	virtual void fillPolygon(
 		int const * xp,
 		int const * yp,
 		int np,
-		LColor::color = LColor::foreground);
+		LColor_color);
 
 	/// draw an arc
-	virtual Painter & arc(
+	virtual void arc(
 		int x, int y,
 		unsigned int w, unsigned int h,
 		int a1, int a2,
-		LColor::color = LColor::foreground);
+		LColor_color);
 
 	/// draw a pixel
-	virtual Painter & point(
+	virtual void point(
 		int x, int y,
-		LColor::color = LColor::foreground);
+		LColor_color);
 
 	/// draw an image from the image cache
-	virtual Painter & image(int x, int y,
+	virtual void image(int x, int y,
 		int w, int h,
-		grfx::Image const & image);
+		graphics::Image const & image);
 
 	/// draw a string at position x, y (y is the baseline)
-	virtual Painter & text(int x, int y,
-		string const & str, LyXFont const & f);
+	virtual void text(int x, int y,
+		std::string const & str, LyXFont const & f);
 
 	/** Draw a string at position x, y (y is the baseline)
 	 *  This is just for fast drawing
 	 */
-	virtual Painter & text(int x, int y,
+	virtual void text(int x, int y,
 		char const * str, size_t l,
 		LyXFont const & f);
 
 	/// draw a char at position x, y (y is the baseline)
-	virtual Painter & text(int x, int y,
+	virtual void text(int x, int y,
 		char c, LyXFont const & f);
 
 	/// draw a wide string at position x, y
-	Painter & text(int x, int y,
+	void text(int x, int y,
 		XChar2b const * str, size_t l,
 		LyXFont const & f);
 
@@ -121,4 +121,7 @@ private:
 	XWorkArea & owner_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // XPAINTER_H
