@@ -7,7 +7,7 @@
  * \author unknown
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef XWORKAREA_H
@@ -16,13 +16,19 @@
 #include "frontends/WorkArea.h"
 #include "XPainter.h"
 
-#include FORMS_H_LOCATION
+#include "LayoutEngine.h"
+
+#include "lyx_forms.h"
+
+class LyXView;
+
+namespace lyx {
+namespace frontend {
 
-///
 class XWorkArea : public WorkArea {
 public:
 	///
-	XWorkArea(int xpos, int ypos, int width, int height);
+	XWorkArea(LyXView & owner, int width, int height);
 	///
 	~XWorkArea();
 	///
@@ -52,9 +58,9 @@ public:
 	/// a selection exists
 	virtual void haveSelection(bool) const;
 	///
-	virtual string const getClipboard() const;
+	virtual std::string const getClipboard() const;
 	///
-	virtual void putClipboard(string const &) const;
+	virtual void putClipboard(std::string const &) const;
 
 	/// handles SelectionRequest X Event, to fill the clipboard
 	int event_cb(XEvent * xev);
@@ -78,6 +84,13 @@ private:
 	bool screen_cleared;
 	/// the current document's height (for scrollbar)
 	int doc_height_;
+	///
+	boost::shared_ptr<Box> wa_box_;
+	///
+	WidgetMap widgets_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // XWORKAREA_H
