@@ -6,18 +6,24 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORMS_GETTEXT_H
 #define FORMS_GETTEXT_H
 
-#include "LString.h"
+#include <string>
+
+namespace lyx {
+namespace frontend {
 
 /// Extract shortcut from "<identifer>|<shortcut>" string
-string const scex(string const &);
+std::string const scex(std::string const &);
 
 /// Extract identifier from "<identifer>|<shortcut>" string
-string const idex(string const &);
+std::string const idex(std::string const &);
+
+} // namespace frontend
+} // namespace lyx
 
 #endif // FORMS_GETTEXT_H
