@@ -6,7 +6,7 @@
  *
  * \author Asger Alstrup
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FONTLOADER_H_
@@ -14,7 +14,9 @@
 
 #include <X11/Xlib.h>
 #include "lyxfont.h"
-#include "LString.h"
+
+namespace lyx {
+namespace frontend {
 
 class FontInfo;
 
@@ -75,4 +77,7 @@ private:
 ///
 extern xfont_loader fontloader;
 
+} // namespace frontend
+} // namespace lyx
+
 #endif
