@@ -7,16 +7,12 @@
  * \author unknown
  * \author John Levon
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef XFONT_METRICS_H
 #define XFONT_METRICS_H
 
-#include "LString.h"
-
-#include "font_metrics.h"
-
 #include <X11/Xlib.h>
 
 class LyXFont;
