@@ -6,7 +6,7 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef XFORMS_RESIZE_H
@@ -14,6 +14,9 @@
 
 #include "forms_fwd.h"
 
+namespace lyx {
+namespace frontend {
+
 /** Ascertains the scaling factor needed to ensure that all labels fit
     within their button.
 
@@ -29,4 +32,7 @@ double get_scale_to_fit(FL_FORM * form);
  */
 void scale_form_horizontally(FL_FORM * form, double factor);
 
+} // namespace frontend
+} // namespace lyx
+
 #endif // XFORMS_RESIZE_H
