@@ -1,32 +1,35 @@
 // -*- C++ -*-
 /**
- *  \file GraphicsCache.h
+ * \file GraphicsCache.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Baruch Even
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  *
- *  grfx::Cache is the manager of the image cache.
- *  It is responsible for creating the grfx::CacheItem's and maintaining them.
+ * lyx::graphics::Cache is the manager of the image cache.
+ * It is responsible for creating the lyx::graphics::CacheItem's
+ * and maintaining them.
  *
- *  grfx::Cache is a singleton class. It is possible to have only one
- *  instance of it at any moment.
+ * lyx::graphics::Cache is a singleton class. It is possible to have only one
+ * instance of it at any moment.
  */
 
 #ifndef GRAPHICSCACHE_H
 #define GRAPHICSCACHE_H
 
-#include "LString.h"
-#include <vector>
 #include <boost/utility.hpp>
 #include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
 
+#include <vector>
+#include <string>
 
-namespace grfx {
+
+namespace lyx {
+namespace graphics {
 
 class CacheItem;
 
@@ -40,16 +43,16 @@ public:
 	 *  Other formats can be loaded if a converter to a loadable format
 	 *  can be defined.
 	 */
-	std::vector<string> loadableFormats() const;
+	std::vector<std::string> loadableFormats() const;
 
 	/// Add a graphics file to the cache.
-	void add(string const & file) const;
+	void add(std::string const & file) const;
 
 	/// Remove a file from the cache.
-	void remove(string const & file) const;
+	void remove(std::string const & file) const;
 
 	/// Returns \c true if the file is in the cache.
-	bool inCache(string const & file) const;
+	bool inCache(std::string const & file) const;
 
 	/** Get the cache item associated with file.
 	 *  Returns an empty container if there is no such item.
@@ -63,7 +66,7 @@ public:
 	 */
 	typedef boost::shared_ptr<CacheItem> ItemPtr;
 	///
-	ItemPtr const item(string const & file) const;
+	ItemPtr const item(std::string const & file) const;
 
 private:
 	/** Make the c-tor, d-tor private so we can control how many objects
@@ -79,6 +82,7 @@ private:
 	boost::scoped_ptr<Impl> const pimpl_;
 };
 
-} // namespace grfx
+} // namespace graphics
+} // namespace lyx
 
 #endif // GRAPHICSCACHE_H
