@@ -1,14 +1,14 @@
 // -*- C++ -*-
 /**
- *  \file GraphicsLoader.h
+ * \file GraphicsLoader.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- *  \author Angus Leeming
+ * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  *
- *  The public face of the graphics cache.
+ * The public face of the graphics cache.
  *
  *  * The user supplies an image file and the display parameters.
  *  * He can change the file or the display parameters through a reset() method.
@@ -18,22 +18,19 @@
  *  * When (status() == Ready), he can use image() to access the loaded image
  *    and pass it to the Painter.
  *
- *  What could be simpler?
+ * What could be simpler?
  */
 
 #ifndef GRAPHICSLOADER_H
 #define GRAPHICSLOADER_H
 
 #include "GraphicsTypes.h"
-#include "LString.h"
 
-#include <boost/signals/signal0.hpp>
 #include <boost/scoped_ptr.hpp>
+#include <boost/signal.hpp>
 
-class Inset;
-class BufferView;
-
-namespace grfx {
+namespace lyx {
+namespace graphics {
 
 class Image;
 class Params;
@@ -43,33 +40,34 @@ public:
 	/// Must use the reset methods to make this instance usable.
 	Loader();
 	/// The image is not transformed, just displayed as-is.
-	Loader(string const & file_with_path, DisplayType = ColorDisplay);
+	Loader(std::string const & file_with_path, DisplayType = ColorDisplay);
 	/// The image is transformed before display.
-	Loader(string const & file_with_path, Params const &);
+	Loader(std::string const & file_with_path, Params const &);
+	///
+	Loader(Loader const &);
 
 	/// Define an empty d-tor out-of-line to keep boost::scoped_ptr happy.
 	~Loader();
 
+	Loader & operator=(Loader const &);
+
 	/// The file can be changed, or the display params, or both.
-	void reset(string const & file_with_path,
+	void reset(std::string const & file_with_path,
 		   DisplayType = ColorDisplay) const;
 	///
-	void reset(string const & file_with_path, Params const &) const;
+	void reset(std::string const & file_with_path, Params const &) const;
 	///
 	void reset(Params const &) const;
 
 	/// Returns the absolute path of the loaded (loading?) file.
-	string const & filename() const;
+	std::string const & filename() const;
 	///
 	bool empty() const { return filename().empty(); }
 
-	/// We are explicit about when we begin the loading process.
-	void startLoading() const;
-
-	/** starting loading of the image is conditional upon the
-	 *  inset being visible or not.
+	/** starting loading of the image is done by a urgency-based
+	 *  decision. Here we only call LoaderQueue::touch to request it.
 	 */
-	void startLoading(Inset const &, BufferView const &) const;
+	void startLoading() const;
 
 	/** Monitor any changes to the file.
 	 *  There is no point monitoring the file before startLoading() is
@@ -90,7 +88,8 @@ public:
 	/** Connect and you'll be informed when the loading status of the image
 	 *  changes.
 	 */
-	typedef boost::signal0<void>::slot_type slot_type;
+	typedef boost::signal<void()> sig_type;
+	typedef sig_type::slot_type slot_type;
 	///
 	boost::signals::connection connect(slot_type const &) const;
 
@@ -106,6 +105,7 @@ private:
 	boost::scoped_ptr<Impl> const pimpl_;
 };
 
-} // namespace grfx
+} // namespace graphics
+} // namespace lyx
 
 #endif // GRAPHICSLOADER_H
