@@ -1,33 +1,37 @@
 // -*- C++ -*-
 /**
- *  \file GraphicsParams.h
+ * \file GraphicsParams.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- *  \author Angus Leeming
+ * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  *
- *  Used internally by the grfx::Image.
+ * Used internally by the lyx::graphics::Image.
  */
 
 #ifndef GRAPHICSPARAMS_H
 #define GRAPHICSPARAMS_H
 
 #include "GraphicsTypes.h"
-#include "LString.h"
+
+#include <string>
+#include <iosfwd>
 
 
-namespace grfx {
+namespace lyx {
+namespace graphics {
 
 /** Parse a string of the form "200pt 500pt 300mm 5in" into a
  *  usable bounding box.
  */
-struct BoundingBox {
+class BoundingBox {
+public:
 	///
 	BoundingBox();
 	///
-	BoundingBox(string const &);
+	BoundingBox(std::string const &);
 
 	/// 0 0 0 0 is empty!
 	bool empty() const;
@@ -41,15 +45,19 @@ struct BoundingBox {
 bool operator==(BoundingBox const &, BoundingBox const &);
 bool operator!=(BoundingBox const &, BoundingBox const &);
 
-struct Params
+std::ostream & operator<<(std::ostream &, BoundingBox const &);
+
+
+class Params
 {
+public:
 	Params();
 
 	DisplayType display;
 	unsigned int scale;
 
 	/// The image filename.
-	string filename;
+	std::string filename;
 
 	/** Note that the BoundingBox is always relative to the BoundingBox
 	 *  as stored in the EPS file.
@@ -61,12 +69,13 @@ struct Params
 	 *  image.
 	 */
 	/// Rotation angle.
-	float angle;
+	double angle;
 };
 
 bool operator==(Params const &, Params const &);
 bool operator!=(Params const &, Params const &);
 
-} // namespace grfx
+} // namespace graphics
+} // namespace lyx
 
 #endif // GRAPHICSPARAMS_H
