@@ -1,27 +1,25 @@
 // -*- C++ -*-
 /**
- *  \file GraphicsTypes.h
+ * \file GraphicsTypes.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- *  \author Angus Leeming
+ * \author Angus Leeming
  *
- *  Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  *
- *  All that header files outside the graphics subdirectory should need to
- *  access.
+ * All that header files outside the graphics subdirectory should need to
+ * access.
  */
 
 #ifndef GRAPHICSTYPES_H
 #define GRAPHICSTYPES_H
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "support/translator.h"
 
-namespace grfx {
+
+namespace lyx {
+namespace graphics {
 
 /// The status of the loading process
 enum ImageStatus {
@@ -65,12 +63,11 @@ enum DisplayType {
 	NoDisplay
 };
 
-/// The translator between the DisplayType and the corresponding lyx string.
-extern Translator<DisplayType, string> displayTranslator;
 
-///
-void setDisplayTranslator();
+/// The translator between the Display enum and corresponding lyx string.
+Translator<DisplayType, std::string> const & displayTranslator();
 
-} // namespace grfx
+} // namespace graphics
+} // namespace lyx
 
 #endif // GRAPHICSTYPES_H
