@@ -1,24 +1,22 @@
 // -*- C++ -*-
 /**
- *  \file PreviewImage.h
+ * \file PreviewImage.h
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef PREVIEWIMAGE_H
 #define PREVIEWIMAGE_H
 
-#include "LString.h"
 #include <boost/scoped_ptr.hpp>
+#include <string>
 
-class Inset;
-class BufferView;
-
-namespace grfx {
+namespace lyx {
+namespace graphics {
 
 class PreviewLoader;
 class Image;
@@ -29,14 +27,14 @@ public:
 	 *  descent = height * (1 - ascent_frac)
 	 */
 	PreviewImage(PreviewLoader & parent,
-		     string const & latex_snippet,
-		     string const & bitmap_file,
+		     std::string const & latex_snippet,
+		     std::string const & bitmap_file,
 		     double ascent_frac);
 	///
 	~PreviewImage();
 
 	///
-	string const & snippet() const;
+	std::string const & snippet() const;
 	///
 	int ascent() const;
 	///
@@ -46,10 +44,8 @@ public:
 
 	/** If the image is not yet loaded (WaitingToLoad), then this method
 	 *  triggers that.
-	 *  inset and bv are passed so we can choose to load only
-	 *  those insets that are visible.
 	 */
-	Image const * image(Inset const & inset, BufferView const & bv) const;
+	Image const * image() const;
 
 private:
 	/// Use the Pimpl idiom to hide the internals.
@@ -58,6 +54,7 @@ private:
 	boost::scoped_ptr<Impl> const pimpl_;
 };
 
-} // namespace grfx
+} // namespace graphics
+} // namespace lyx
 
 #endif // PREVIEWIMAGE_H
