@@ -6,12 +6,13 @@
  *
  * \author Lars Gullik Bjnnes
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef InsetTheorem_H
 #define InsetTheorem_H
 
+
 #include "insetcollapsable.h"
 
 /** The theorem inset
@@ -22,17 +23,23 @@ public:
 	///
 	InsetTheorem();
 	///
-	void write(Buffer const * buf, std::ostream & os) const;
-	///
-	virtual Inset * clone(Buffer const &, bool same_id = false) const;
+	void write(Buffer const & buf, std::ostream & os) const;
 	///
 	Inset::Code lyxCode() const { return Inset::THEOREM_CODE; }
 	///
-	bool display() const { return true; }
+	void metrics(MetricsInfo &, Dimension &) const;
 	///
-	int latex(Buffer const *, std::ostream &, bool fragile, bool fp) const;
+	void draw(PainterInfo & pi, int x, int y) const;
+	///
+	int latex(Buffer const &, std::ostream &,
+		  OutputParams const &) const;
 	///
 	string const editMessage() const;
+private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
+
+	///
+	mutable unsigned int center_indent_;
 };
 
 #endif
