@@ -1,18 +1,20 @@
 // -*- C++ -*-
 /**
  * \file intl.h
- * Copyright 1995-2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author unknown
- * \author John Levon <moz@compsoc.man.ac.uk>
+ * \author Lars Gullik Bjnnes
+ * \author Angus Leeming
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
-
 #ifndef INTL_H
 #define INTL_H
 
-#include "LString.h"
 #include "trans_mgr.h"
 
 
@@ -55,9 +57,9 @@ private:
 	/// is key mapping enabled ?
 	bool keymapon;
 	/// the primary language keymap
-	string & prim_lang;
+	std::string & prim_lang;
 	/// the secondary language keymap
-	string & sec_lang;
+	std::string & sec_lang;
 	/// the translation manager
 	TransManager trans;
 };
