@@ -1,32 +1,33 @@
 // -*- C++ -*-
-/* This file is part of
- * ======================================================
+/**
+ * \file lastfiles.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
- *           LyX, The Document Processor
+ * \author Lars Gullik Bjnnes
  *
- *           Copyright 1995 Matthias Ettrich
- *           Copyright 1995-2001 The LyX Team.
- *
- * ====================================================== */
+ * Full author contact details are available in file CREDITS.
+ */
 
 #ifndef LASTFILES_H
 #define LASTFILES_H
 
-#include <deque>
-
-#include "LString.h"
 #include <boost/utility.hpp>
 
+#include <deque>
+#include <string>
+
+const long maxlastfiles = 20;
+
 /** The latest documents loaded.
-    This class takes care of the last .lyx files used by the LyX user. It
-    both reads and writes this information to a file. The number of files
-    kept are user defined, but defaults to four.
-    @author Lars Gullik Bjnnes
-*/
+ *  This class takes care of the last .lyx files used by the LyX user. It
+ *  both reads and writes this information to a file. The number of files
+ *  kept are user defined, but defaults to four.
+ */
 class LastFiles : boost::noncopyable {
 public:
 	///
-	typedef std::deque<string> Files;
+	typedef std::deque<std::string> Files;
 
 	///
 	typedef Files::const_iterator const_iterator;
@@ -37,7 +38,7 @@ public:
 	    @param num number of files to remember.
 	*/
 	explicit
-	LastFiles(string const & file,
+	LastFiles(std::string const & file,
 		  bool dostat = true, unsigned int num = 4);
 
 	/** Insert #file# into the list.
@@ -47,18 +48,18 @@ public:
 	    file in the list is popped from the end.
 	    @param file the file to insert in the list.
 	*/
-	void newFile(string const & file);
+	void newFile(std::string const & file);
 	/** Writes the lastfiles table to disk.
 	    Writes one file on each line, this way we can at least have
 	    some special chars (e.g. space), but newline in filenames
 	    are thus not allowed.
 	    @param file the file we write the lastfiles list to.
 	*/
-	void writeFile(string const & file) const;
+	void writeFile(std::string const & file) const;
 	/** Return file #n# in the lastfiles list.
 	    @param n number in the list to get
 	*/
-	string const operator[](unsigned int n) const;
+	std::string const operator[](unsigned int n) const;
 	/// Iterator to the beginning of the list.
 	Files::const_iterator begin() const { return files.begin(); }
 	/// Iterator to the end of the list.
@@ -95,7 +96,7 @@ private:
 	    LastFiles has been initialized with #dostat = false#.
 	    @param file the file containing the lastfiles.
 	*/
-	void readFile(string const & file);
+	void readFile(std::string const & file);
 	/** Used by the constructor to set the number of stored last files.
 	    @param num the number of lastfiles to set.
 	*/
