@@ -1,29 +1,37 @@
 // -*- C++ -*-
+/**
+ * \file lyxlex_pimpl.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Lars Gullik Bjnnes
+ *
+ * Full author contact details are available in file CREDITS.
+ */
 
 #ifndef LYXLEX_PIMPL_H
 #define LYXLEX_PIMPL_H
 
-#include <fstream>
-#include <stack>
-#include <boost/utility.hpp>
-
 #include "lyxlex.h"
 
+# include "support/gzstream.h"
+
+#include <boost/utility.hpp>
+
+#include <fstream>
+#include <istream>
+#include <stack>
+#include <vector>
 
 ///
-struct LyXLex::Pimpl : boost::noncopyable {
-	///
-	enum {
-		///
-		LEX_MAX_BUFF = 2048
-	};
-
+class LyXLex::Pimpl : boost::noncopyable {
+public:
 	///
 	Pimpl(keyword_item * tab, int num);
 	///
-	string const getString() const;
+	std::string const getString() const;
 	///
-	void printError(string const & message) const;
+	void printError(std::string const & message) const;
 	///
 	void printTable(std::ostream & os);
 	///
@@ -31,7 +39,7 @@ struct LyXLex::Pimpl : boost::noncopyable {
 	///
 	void popTable();
 	///
-	bool setFile(string const & filename);
+	bool setFile(std::string const & filename);
 	///
 	void setStream(std::istream & i);
 	///
@@ -47,32 +55,37 @@ struct LyXLex::Pimpl : boost::noncopyable {
 	///
 	bool nextToken();
 	///
-	void pushToken(string const &);
-	/// fb__ is only used to open files, the stream is accessed through is
-	std::filebuf fb__;
+	void pushToken(std::string const &);
+	/// fb_ is only used to open files, the stream is accessed through is.
+	std::filebuf fb_;
+
+	/// gz_ is only used to open files, the stream is accessed through is.
+	gz::gzstreambuf gz_;
+
 	/// the stream that we use.
 	std::istream is;
 	///
-	string name;
+	std::string name;
 	///
 	keyword_item * table;
 	///
 	int no_items;
 	///
-	char buff[LEX_MAX_BUFF];
+	std::vector<char> buff;
 	///
 	int status;
 	///
 	int lineno;
 	///
-	string pushTok;
+	std::string pushTok;
 	///
 	char commentChar;
 private:
 	///
 	void verifyTable();
 	///
-	struct pushed_table {
+	class pushed_table {
+	public:
 		///
 		pushed_table()
 			: table_elem(0), table_siz(0) {}
