@@ -15,19 +15,17 @@
 #include "math_nestinset.h"
 
 
-/// Inset for AMSTeX's \boldsymbol 
+/// Inset for AMSTeX's \boldsymbol
 class MathBoldsymbolInset : public MathNestInset {
 public:
 	///
 	MathBoldsymbolInset();
 	///
-	MathInset * clone() const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void metrics(MathMetricsInfo & mi) const;
+	void draw(PainterInfo & pi, int x, int y) const;
 	///
-	void draw(MathPainterInfo & pi, int x, int y) const;
-	///
-	void metricsT(TextMetricsInfo const & mi) const;
+	void metricsT(TextMetricsInfo const & mi, Dimension & dim) const;
 	///
 	void drawT(TextPainter & pi, int x, int y) const;
 	///
@@ -36,6 +34,8 @@ public:
 	void write(WriteStream & os) const;
 	///
 	void infoize(std::ostream & os) const;
+private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
 };
 
 #endif
