@@ -1,19 +1,21 @@
 // -*- C++ -*-
+/**
+ * \file math_braceinset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATH_BRACEINSET_H
 #define MATH_BRACEINSET_H
 
 #include "math_nestinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-/** Extra nesting
- *  \author Andr Pnitz
- *
- * Full author contact details are available in file CREDITS
-*/
 
+/// Extra nesting
 class MathBraceInset : public MathNestInset {
 public:
 	///
@@ -21,31 +23,29 @@ public:
 	///
 	MathBraceInset(MathArray const & ar);
 	///
-	MathInset * clone() const;
+	MathBraceInset const * asBraceInset() const { return this; }
 	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	void metrics(MathMetricsInfo & mi) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void draw(MathPainterInfo &, int x, int y) const;
+	void draw(PainterInfo &, int x, int y) const;
 	///
 	void write(WriteStream & os) const;
 	/// write normalized content
 	void normalize(NormalStream & ns) const;
 	///
-	void maplize(MapleStream &) const;
+	void maple(MapleStream &) const;
 	///
-	void mathematicize(MathematicaStream &) const;
+	void mathematica(MathematicaStream &) const;
 	///
-	void octavize(OctaveStream &) const;
+	void octave(OctaveStream &) const;
 	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void infoize(std::ostream & os) const;
-
 private:
-	/// width of brace character
-	mutable int wid_;
+	virtual std::auto_ptr<InsetBase> doClone() const;
 };
 
 #endif
