@@ -1,41 +1,41 @@
 // -*- C++ -*-
+/**
+ * \file math_fontinset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATH_FONTINSET_H
 #define MATH_FONTINSET_H
 
 #include "math_nestinset.h"
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-/** Inset for font changes
- *  \author Andr Pnitz
- *
- * Full author contact details are available in file CREDITS
- */
 
 class latexkeys;
 
+/// Inset for font changes
 class MathFontInset : public MathNestInset {
 public:
 	///
 	explicit MathFontInset(latexkeys const * key);
 	///
-	MathInset * clone() const;
-	///
 	MathFontInset * asFontInset() { return this; }
 	///
 	MathFontInset const * asFontInset() const { return this; }
 	/// are we in math mode, text mode, or unsure?
 	mode_type currentMode() const;
 	///
-	string name() const;
+	std::string name() const;
 	///
-	void metrics(MathMetricsInfo & mi) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void draw(MathPainterInfo & pi, int x, int y) const;
+	void draw(PainterInfo & pi, int x, int y) const;
 	///
-	void metricsT(TextMetricsInfo const & mi) const;
+	void metricsT(TextMetricsInfo const & mi, Dimension & dim) const;
 	///
 	void drawT(TextPainter & pi, int x, int y) const;
 	///
@@ -44,6 +44,7 @@ public:
 	void infoize(std::ostream & os) const;
 
 private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
 	/// the font to be used on screen
 	latexkeys const * key_;
 };
