@@ -1,25 +1,29 @@
 // -*- C++ -*-
+/**
+ * \file math_frameboxinset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATH_FRAMEBOXINSET_H
 #define MATH_FRAMEBOXINSET_H
 
 #include "math_nestinset.h"
 
-/** Extra nesting
- *  \author Andr Pnitz
- *
- * Full author contact details are available in file CREDITS
-*/
 
+/// Extra nesting
 class MathFrameboxInset : public MathNestInset {
 public:
 	///
 	MathFrameboxInset();
 	///
-	MathInset * clone() const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void metrics(MathMetricsInfo & mi) const;
-	///
-	void draw(MathPainterInfo & pi, int x, int y) const;
+	void draw(PainterInfo & pi, int x, int y) const;
 	///
 	void write(WriteStream & os) const;
 	/// write normalized content
@@ -27,6 +31,7 @@ public:
 	///
 	mode_type currentMode() const { return TEXT_MODE; }
 private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
 	/// width of '[' in current font
 	mutable int w_;
 };
