@@ -1,7 +1,18 @@
 // -*- C++ -*-
+/**
+ * \file math_liminset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATH_LIMINSET_H
 #define MATH_LIMINSET_H
 
+
 // lim_{x->x0} f(x) in one block
 // for interfacing external programs
 
@@ -12,22 +23,22 @@ public:
 	///
 	MathLimInset(MathArray const & f, MathArray const & x, MathArray const & x0);
 	///
-	MathInset * clone() const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void metrics(MathMetricsInfo & mi) const;
-	///
-	void draw(MathPainterInfo & pi, int x, int y) const;
+	void draw(PainterInfo & pi, int x, int y) const;
 
 	///
 	void normalize(NormalStream &) const;
 	///
-	void maplize(MapleStream &) const;
+	void maple(MapleStream &) const;
 	///
-	void mathematicize(MathematicaStream &) const;
+	void mathematica(MathematicaStream &) const;
 	///
 	void mathmlize(MathMLStream &) const;
 	///
 	void write(WriteStream & os) const;
+private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
 };
 
 #endif
