@@ -121,8 +121,8 @@ private:
 	int ndes() const;
 	/// where do we have to draw the scripts?
 	bool hasLimits() const;
-	/// clean up empty cells
-	void notifyCursorLeaves(LCursor & cur);
+	/// clean up empty cells and return true if a cell has been deleted.
+	bool notifyCursorLeaves(LCursor & cur);
 
 	/// possible subscript (index 0) and superscript (index 1)
 	bool cell_1_is_up_;
