@@ -1,30 +1,34 @@
 // -*- C++ -*-
+/**
+ * \file math_sizeinset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATHSIZEINSET_H
 #define MATHSIZEINSET_H
 
 #include "math_nestinset.h"
-#include "math_metricsinfo.h"
+#include "metricsinfo.h"
 
-/** An inset for \scriptsize etc
- *  \author Andr Pnitz
- *
- * Full author contact details are available in file CREDITS
-*/
 
 class latexkeys;
 
+/// An inset for \scriptsize etc.
 class MathSizeInset : public MathNestInset {
 public:
 	///
 	explicit MathSizeInset(latexkeys const * l);
-	///
-	MathInset * clone() const;
 	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	void metrics(MathMetricsInfo & st) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
-	void draw(MathPainterInfo &, int x, int y) const;
+	void draw(PainterInfo &, int x, int y) const;
 
 	///
 	void write(WriteStream & os) const;
@@ -32,12 +36,12 @@ public:
 	void normalize(NormalStream &) const;
 	///
 	void infoize(std::ostream & os) const;
-
 private:
+	virtual std::auto_ptr<InsetBase> doClone() const;
 	///
 	latexkeys const * key_;
 	///
-	MathStyles const style_;
+	Styles const style_;
 };
 
 #endif
