@@ -1,7 +1,18 @@
 // -*- C++ -*-
+/**
+ * \file math_xymatrixinset.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Andr Pnitz
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef MATH_XYMATRIX_H
 #define MATH_XYMATRIX_H
 
+#include "lyxlength.h"
 #include "math_gridinset.h"
 
 
@@ -10,9 +21,7 @@ public:
 	///
 	MathXYMatrixInset();
 	///
-	MathInset * clone() const;
-	///
-	void metrics(MathMetricsInfo & st) const;
+	void metrics(MetricsInfo &, Dimension &) const;
 	///
 	MathXYMatrixInset const * asXYMatrixInset() const { return this; }
 	///
@@ -25,9 +34,14 @@ public:
 	///
 	void write(WriteStream & os) const;
 	///
+	void infoize(std::ostream & os) const;
+	///
 	void normalize(NormalStream &) const;
 	///
-	void maplize(MapleStream &) const;
+	void maple(MapleStream &) const;
+private:
+	///
+	virtual std::auto_ptr<InsetBase> doClone() const;
 };
 
 #endif
