@@ -6,7 +6,7 @@
  *
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  *
  * FileMonitor monitors a file and informs a listener when that file has
  * changed.
@@ -15,27 +15,28 @@
 #ifndef FILEMONITOR_H
 #define FILEMONITOR_H
 
-#include "LString.h"
-
 #include <boost/utility.hpp>
 #include <boost/scoped_ptr.hpp>
-#include <boost/signals/signal0.hpp>
+#include <boost/signal.hpp>
+
+namespace lyx {
+namespace support {
 
 class FileMonitor : boost::noncopyable {
 public:
 	/** Once monitoring begins, the file will be monitored every
 	 *  interval ms.
 	 */
-	FileMonitor(string const & file_with_path, int interval);
+	FileMonitor(std::string const & file_with_path, int interval);
 
 	/// Define an empty d-tor out-of-line to keep boost::scoped_ptr happy.
 	~FileMonitor();
 
 	///
-	void reset(string const & file_with_path) const;
+	void reset(std::string const & file_with_path) const;
 
 	///
-	string const & filename() const;
+	std::string const & filename() const;
 
 	/// Begin monitoring the file
 	void start() const;
@@ -51,7 +52,8 @@ public:
 	unsigned long checksum() const;
 
 	/// Connect and you'll be informed when the file has changed.
-	typedef boost::signal0<void>::slot_type slot_type;
+	typedef boost::signal<void()> FileChangedSig;
+	typedef FileChangedSig::slot_type slot_type;
 	///
 	boost::signals::connection connect(slot_type const &) const;
 
@@ -63,4 +65,7 @@ private:
 	boost::scoped_ptr<Impl> const pimpl_;
 };
 
+} // namespace support
+} // namespace lyx
+
 #endif // FILEMONITOR_H
