@@ -1,8 +1,18 @@
 // -*- C++ -*-
+/**
+ * \file lyxmanip.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Lars Gullik Bjnnes
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef LYX_MANIP_H
 #define LYX_MANIP_H
 
-#include "support/LOstream.h"
+#include "support/std_ostream.h"
 
 ///
 struct NewLineAndDepth_ {
@@ -22,7 +32,7 @@ NewLineAndDepth_ newlineAndDepth(int n)
 inline
 std::ostream & operator<<(std::ostream & os, NewLineAndDepth_ const & nlad_)
 {
-	os << string(nlad_.depth_, ' ');
+	os << std::string(nlad_.depth_, ' ');
 	return os;
 }
 
