@@ -1,11 +1,22 @@
 // -*- C++ -*-
-#ifndef Trans_Decl_h
-#define Trans_Decl_h
+/**
+ * \file trans_decl.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Lars Gullik Bjnnes
+ * \author Matthias Ettrich
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
+#ifndef TRANS_DECL_H
+#define TRANS_DECL_H
 
-#include "LString.h"
 #include "tex-accent.h"
 
 #include <list>
+#include <string>
 
 
 ///
@@ -13,7 +24,7 @@ struct Keyexc {
 	/// character to make exception
 	char c;
 	/// exception data
-	string data;
+	std::string data;
 	/// Combination with another deadkey
 	bool combined;
 	/// The accent comined with
@@ -24,9 +35,10 @@ struct Keyexc {
 typedef std::list<Keyexc> KmodException;
 
 ///
-struct KmodInfo {
+class KmodInfo {
+public:
 	///
-	string data;
+	std::string data;
 	///
 	tex_accent accent;
 	///
