@@ -1,11 +1,23 @@
 // -*- C++ -*-
+/**
+ * \file trans_mgr.h
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
+ *
+ * \author Lars Gullik Bjnnes
+ * \author Matthias Ettrich
+ * \author John Levon
+ *
+ * Full author contact details are available in file CREDITS.
+ */
+
 #ifndef TRANS_MANAGER_H
 #define TRANS_MANAGER_H
 
-#include "tex-accent.h"
-#include "trans_decl.h"
 #include "chset.h"
-#include "LString.h"
+#include "trans_decl.h"
+
+#include <boost/scoped_ptr.hpp>
 
 class LyXText;
 class Trans;
@@ -16,11 +28,11 @@ public:
 	///
 	virtual ~TransState() {}
 	///
-	virtual string const normalkey(char) = 0;
+	virtual std::string const normalkey(char) = 0;
 	///
 	virtual bool backspace() = 0;
 	///
-	virtual string const deadkey(char, KmodInfo) = 0;
+	virtual std::string const deadkey(char, KmodInfo) = 0;
 	///
 	static char const TOKEN_SEP;
 };
@@ -57,16 +69,16 @@ public:
 
 
 /// Init State
-class TransInitState :	virtual public TransFSMData, public TransState {
+class TransInitState :virtual public TransFSMData, public TransState {
 public:
 	///
 	TransInitState();
 	///
-	virtual string const normalkey(char);
+	virtual std::string const normalkey(char);
 	///
 	virtual bool backspace() { return true; }
 	///
-	virtual string const deadkey(char, KmodInfo);
+	virtual std::string const deadkey(char, KmodInfo);
 };
 
 
@@ -76,14 +88,14 @@ public:
 	///
 	TransDeadkeyState();
 	///
-	virtual string const normalkey(char);
+	virtual std::string const normalkey(char);
 	///
 	virtual bool backspace() {
 		currentState = init_state_;
 		return false;
 	}
 	///
-	virtual string const deadkey(char, KmodInfo);
+	virtual std::string const deadkey(char, KmodInfo);
 };
 
 
@@ -93,7 +105,7 @@ public:
 	///
 	TransCombinedState();
 	///
-	virtual string const normalkey(char);
+	virtual std::string const normalkey(char);
 	///
 	virtual bool backspace() {
 		// cancel the second deadkey
@@ -104,7 +116,7 @@ public:
 		return false;
 	}
 	///
-	virtual string const deadkey(char, KmodInfo);
+	virtual std::string const deadkey(char, KmodInfo);
 };
 
 
@@ -127,26 +139,26 @@ private:
 	///
 	Trans * active_;
 	///
-	Trans * t1_;
+	boost::scoped_ptr<Trans> t1_;
 	///
-	Trans * t2_;
+	boost::scoped_ptr<Trans> t2_;
 	///
 	static Trans default_;
 	///
 	CharacterSet chset_;
 	///
-	void insert(string const &, LyXText *);
+	void insert(std::string const &, LyXText *);
 	///
-	void insertVerbatim(string const &, LyXText *);
+	void insertVerbatim(std::string const &, LyXText *);
 public:
 	///
 	TransManager();
 	///
-	virtual ~TransManager();
+	~TransManager();
 	///
-	int SetPrimary(string const &);
+	int SetPrimary(std::string const &);
 	///
-	int SetSecondary(string const &);
+	int SetSecondary(std::string const &);
 	///
 	void EnablePrimary();
 	///
@@ -154,7 +166,7 @@ public:
 	///
 	void DisableKeymap();
 	///
-	bool setCharset(string const &);
+	bool setCharset(std::string const &);
 	///
 	bool backspace() {
 		return trans_fsm_.currentState->backspace();
@@ -162,23 +174,23 @@ public:
 	///
 	void TranslateAndInsert(char, LyXText *);
 	///
-	string const deadkey(char, KmodInfo);
+	std::string const deadkey(char, KmodInfo);
 	///
-	string const normalkey(char);
+	std::string const normalkey(char);
 	///
 	void deadkey(char, tex_accent, LyXText *);
 };
 
 
 inline
-string const TransManager::normalkey(char c)
+std::string const TransManager::normalkey(char c)
 {
 	return trans_fsm_.currentState->normalkey(c);
 }
 
 
 inline
-string const TransManager::deadkey(char c, KmodInfo t)
+std::string const TransManager::deadkey(char c, KmodInfo t)
 {
 	return trans_fsm_.currentState->deadkey(c, t);
 }
