@@ -1,10 +1,12 @@
 // -*- C++ -*-
 /**
  * \file vspace.h
- * Copyright 1995-2002 the LyX Team
- * Read the file COPYING
+ * This file is part of LyX, the document processor.
+ * Licence details can be found in the file COPYING.
  *
  * \author Matthias Ettrich
+ *
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef VSPACE_H
@@ -12,7 +14,6 @@
 
 #include "lyxgluelength.h"
 
-#include "LString.h"
 
 class BufferParams;
 class BufferView;
@@ -23,7 +24,6 @@ class VSpace {
 public:
 	/// The different kinds of spaces.
 	enum vspace_kind {
-		NONE, ///< no added vertical space
 		DEFSKIP,
 		SMALLSKIP,
 		MEDSKIP,
@@ -41,12 +41,12 @@ public:
 	explicit VSpace(LyXGlueLength const & l);
 
 	/// Constructor for reading from a .lyx file
-	explicit VSpace(string const & data);
+	explicit VSpace(std::string const & data);
 
 	/// return the type of vertical space
 	vspace_kind kind() const;
 	/// return the length of this space
-	LyXGlueLength length() const;
+	LyXGlueLength const & length() const;
 
 	// a flag that switches between \vspace and \vspace*
 	bool keep() const;
@@ -58,11 +58,14 @@ public:
 	// conversion
 
 	/// how it goes into the LyX file
-	string const asLyXCommand() const;
+	std::string const asLyXCommand() const;
 	/// the latex representation
-	string const asLatexCommand(BufferParams const & params) const;
+	std::string const asLatexCommand(BufferParams const & params) const;
+	/// how it is seen in the LyX window
+	std::string const asGUIName() const;
 	/// the size of the space on-screen
-	int inPixels(BufferView const * bv) const;
+	int inPixels(BufferView const & bv) const;
+
 private:
 	/// This VSpace kind
 	vspace_kind kind_;
